@@ -18,10 +18,8 @@ async def post_gather(hub, ctx) -> Dict[str, Any]:
 
     for name, raw_profile in profiles.items():
         new_profile = {}
-
-        # Apply modifications to the profile before using it
-        await hub.tool.aws.acct.init.modify(name, raw_profile, new_profile)
-
+        # Apply modifications to the new_profile before using it
+        await hub.tool.aws.acct.key_name.modify(name, raw_profile, new_profile)
         # Log whether this is a new profile or if the mods are overwriting an existing profile
         if name in profiles:
             hub.log.debug(f"Modified profile '{name}' for the current run")
