@@ -4,6 +4,10 @@ CLI_CONFIG = {
         "subcommands": ["aws"],
         "dyne": "pop_create",
     },
+    "service_resources": {
+        "subcommands": ["aws"],
+        "dyne": "pop_create",
+    },
     "sync_sls_name_and_name_tag": {
         "action": "store_true",
         "subcommands": ["state"],
@@ -18,6 +22,12 @@ CONFIG = {
         "help": "The cloud services to target, defaults to all",
         "dyne": "pop_create",
     },
+    "service_resources": {
+        "default": [],
+        "nargs": "*",
+        "help": "The cloud service resources to target in autogen, defaults to all",
+        "dyne": "pop_create",
+    },
     "sync_sls_name_and_name_tag": {
         "default": False,
         "help": "If set to true, tags for a resource will be modified to use the SLS name as a Name tag",
