@@ -1,6 +1,7 @@
 """
 Plugin for aws enforced state management
 """
+import copy
 import json
 import pathlib
 from typing import Any
@@ -27,7 +28,8 @@ async def get_state(hub, ctx) -> Dict[str, Any]:
     """
     esm_profile = await hub.esm.aws.generate_esm_profile(ctx)
     try:
-        client = await hub.tool.boto3.client.get_client(ctx, service_name="s3")
+        esm_ctx = _populate_esm_ctx(esm_profile, ctx)
+        client = await hub.tool.boto3.client.get_client(esm_ctx, service_name="s3")
         content = client.get_object(
             Bucket=esm_profile.get("bucket"),
             Key=esm_profile.get("key"),
@@ -69,8 +71,9 @@ async def set_state(hub, ctx, state: Dict[str, Any]):
     """
     esm_profile = await hub.esm.aws.generate_esm_profile(ctx)
     try:
+        esm_ctx = _populate_esm_ctx(esm_profile, ctx)
         ret = await hub.exec.boto3.client.s3.put_object(
-            ctx,
+            esm_ctx,
             Bucket=esm_profile.get("bucket"),
             Body=bytes(json.dumps(state, default=str), "utf-8"),
             Key=esm_profile.get("key"),
@@ -142,8 +145,9 @@ async def enter(hub, ctx):
     try:
         # Put item with conditional expression to acquire the lock. The conditional check and put operation is atomic.
         # This ensures that the S3 bucket file can be locked properly.
+        esm_ctx = _populate_esm_ctx(esm_profile, ctx)
         db_resource = await hub.tool.boto3.resource.create(
-            ctx, "dynamodb", "Table", esm_profile.get("dynamodb_table")
+            esm_ctx, "dynamodb", "Table", esm_profile.get("dynamodb_table")
         )
         db_resource.put_item(
             Item={"LockID": f"{esm_profile.get('bucket')}/{esm_profile.get('key')}"},
@@ -185,8 +189,9 @@ async def exit_(hub, ctx, handle: pathlib.Path, exception: Exception):
         raise ValueError("ESM profile is required to support remote ESM storage.")
     try:
         # Delete item with conditional expression to release the lock
+        esm_ctx = _populate_esm_ctx(esm_profile, ctx)
         db_resource = await hub.tool.boto3.resource.create(
-            ctx, "dynamodb", "Table", esm_profile.get("dynamodb_table")
+            esm_ctx, "dynamodb", "Table", esm_profile.get("dynamodb_table")
         )
         db_resource.delete_item(
             Key={"LockID": f"{esm_profile.get('bucket')}/{esm_profile.get('key')}"},
@@ -206,3 +211,15 @@ async def exit_(hub, ctx, handle: pathlib.Path, exception: Exception):
                 f" has been previously released."
             )
             return
+
+
+def _populate_esm_ctx(esm_profile: dict, ctx: dict):
+    # If esm has a region_name, we should use it when connecting to the dynamodb
+    if esm_profile.get("region_name") is not None and esm_profile.get(
+        "region_name"
+    ) != ctx.get("acct", {}).get("region_name"):
+        esm_ctx = copy.deepcopy(ctx)
+        esm_ctx["acct"]["region_name"] = esm_profile.get("region_name")
+        return esm_ctx
+
+    return ctx
