@@ -55,7 +55,7 @@ async def get(
         if get_method_response["ret"]:
             result[
                 "ret"
-            ] = await hub.tool.aws.apigateway.method_response.convert_raw_method_response_to_present(
+            ] = hub.tool.aws.apigateway.method_response.convert_raw_method_response_to_present(
                 idem_resource_name=name,
                 raw_resource=get_method_response["ret"],
                 resource_id=resource_id,
