@@ -47,7 +47,7 @@ async def get(hub, ctx, name: str, resource_id: str = None):
         ctx, resource_id=resource_id
     )
     if not before["result"]:
-        if "DBParameterGroupNotFoundFault" in str(before["comment"]):
+        if "ParameterGroupNotFound" in str(before["comment"]):
             result["comment"].append(
                 hub.tool.aws.comment_utils.get_empty_comment(
                     resource_type=RESOURCE_TYPE,
