@@ -10,14 +10,18 @@ async def update_tags(
     old_tags: Dict[str, Any],
     new_tags: Dict[str, Any],
 ):
-    """
-    Update tags of AWS Dynamo DB resources
+    """Update tags of AWS Dynamo DB resources
 
     Args:
-        resource_arn: Identifies the Amazon DynamoDB resource to which tags should be added.
+        resource_arn:
+            Identifies the Amazon DynamoDB resource to which tags should be added.
             This value is an Amazon Resource Name (ARN).
-        old_tags: Dict of existing tags
-        new_tags: Dict of new tags
+
+        old_tags:
+            Dict of existing tags.
+
+        new_tags:
+            Dict of new tags.
 
     Returns:
         {"result": True|False, "comment": ("A tuple",), "ret": dict of updated tags}
