@@ -74,7 +74,7 @@ async def get(
 async def list_(
     hub,
     ctx,
-    name: str,
+    name: str = None,
     filters: List = None,
     tags: Dict[str, str] = None,
 ) -> Dict:
@@ -83,7 +83,7 @@ async def list_(
     The function returns empty list when no resource is found.
 
     Args:
-        name(str):
+        name(str, Optional):
             The name of the Idem state.
 
         filters(list, Optional):
