@@ -66,13 +66,13 @@ async def get(
     return result
 
 
-async def list_(hub, ctx, name, filters: List = None) -> Dict:
+async def list_(hub, ctx, name: str = None, filters: List = None) -> Dict:
     """Fetch a list of flow_logs from AWS.
 
     The function returns empty list when no resource is found.
 
     Args:
-        name(str):
+        name(str, Optional):
             The name of the Idem state.
 
         filters(list, Optional):
