@@ -558,14 +558,23 @@ async def get(
             Filters=filters,
         )
 
-    # If there was an error in the call then report failure
     if not ret["result"]:
+        if "InvalidInstanceID.NotFound" in str(ret["comment"]):
+            result["comment"].append(
+                hub.tool.aws.comment_utils.get_empty_comment(
+                    resource_type="aws.ec2.instance", name=name
+                )
+            )
+            result["comment"] += list(ret["comment"])
+            return result
         result["comment"] += list(ret["comment"])
         result["result"] = False
         return result
 
-    present_states = await hub.tool.aws.ec2.instance.state.convert_to_present(
-        ctx, ret.ret, name=name
+    present_states = (
+        await hub.tool.aws.ec2.instance.state.convert_instance_to_present_async(
+            ctx, ret.ret, name=name
+        )
     )
 
     # If the resource can't be found but there were no results then "result" is True and "ret" is None
@@ -609,8 +618,10 @@ async def list_(hub, ctx, *, name: str = None, filters: List = None) -> Dict:
         result["result"] = False
         return result
 
-    present_states = await hub.tool.aws.ec2.instance.state.convert_to_present(
-        ctx, ret.ret
+    present_states = (
+        await hub.tool.aws.ec2.instance.state.convert_instance_to_present_async(
+            ctx, ret.ret
+        )
     )
     if not present_states:
         result["comment"].append(
