@@ -62,12 +62,12 @@ async def get(hub, ctx, name, resource_id: str = None, filters: List = None):
     return result
 
 
-async def list_(hub, ctx, name, filters: List = None) -> Dict:
+async def list_(hub, ctx, name: str = None, filters: List = None) -> Dict:
     """
     Fetch a list of route table from AWS. The function returns empty list when no resource is found.
 
     Args:
-        name(str):
+        name(str, Optional):
             An Idem state name.
 
         filters(list[dict[str, Any]], Optional):
