@@ -13,15 +13,42 @@ async def get(
     filters: List = None,
 ) -> Dict:
     """
-    Get a VPC resource from AWS. Supply one of the inputs as the filter.
+    Get a VPC resource from AWS
 
     Args:
-        name(str): The name of the Idem state.
-        resource_id(str, Optional): AWS VPC id to identify the resource.
-        default(bool, Optional): Indicate whether the VPC is the default VPC.
-        filters(list, Optional): One or more filters: for example, tag :<key>, tag-key. A complete list of filters can be found at
-         https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Client.describe_vpcs
+        name (str):
+            The name of the Idem state
 
+        resource_id (str, Optional):
+            ID of the VPC
+
+        default(bool, Optional):
+            Indicate whether the VPC is the default VPC
+
+        filters(list, Optional):
+            One or more filters: for example, tag :<key>, tag-key. A complete list of filters can be found at
+            https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Client.describe_vpcs
+
+    Returns:
+        Dict[str, Any]:
+            Returns VPC in present format
+
+    Examples:
+        Calling this exec module function from the cli with filters
+
+        .. code-block:: bash
+
+            idem exec aws.ec2.vpc.get name="my_resource"
+
+        Using in a state:
+
+        .. code-block:: yaml
+
+            my_unmanaged_resource:
+              exec.run:
+                - path: aws.ec2.vpc.get
+                - kwargs:
+                    name: my_resource
     """
     result = dict(comment=[], ret=None, result=True)
     ret = await hub.tool.aws.ec2.vpc.search_raw(
@@ -56,7 +83,9 @@ async def get(
         result["comment"].append(
             f"More than one aws.ec2.vpc resource was found. Use resource {resource.get('VpcId')}"
         )
-    result["ret"] = await hub.tool.aws.ec2.conversion_utils.convert_raw_vpc_to_present(
+    result[
+        "ret"
+    ] = await hub.tool.aws.ec2.conversion_utils.convert_raw_vpc_to_present_async(
         ctx, raw_resource=resource, idem_resource_name=name
     )
     return result
@@ -66,19 +95,39 @@ async def list_(
     hub, ctx, name: str = None, filters: List = None, default: bool = None
 ) -> Dict:
     """
-    Use an un-managed VPC as a data-source. Supply one of the inputs as the filter.
+    Get a list of VPC resources from AWS
 
     Args:
         name (str, Optional):
-            The name of the Idem state.
+            The name of the Idem state
 
-        default (bool, Optional):
-            Indicate whether the VPC is the default VPC.
+        default(bool, Optional):
+            Indicate whether the VPC is the default VPC
 
-        filters (list, Optional):
+        filters(list, Optional):
             One or more filters: for example, tag :<key>, tag-key. A complete list of filters can be found at
             https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Client.describe_vpcs
 
+    Returns:
+        Dict[str, Any]:
+            Returns VPC in present format
+
+    Examples:
+        Calling this exec module function from the cli with filters
+
+        .. code-block:: bash
+
+            idem exec aws.ec2.vpc.get name="my_resource"
+
+        Using in a state:
+
+        .. code-block:: yaml
+
+            my_unmanaged_resource:
+              exec.run:
+                - path: aws.ec2.vpc.get
+                - kwargs:
+                    name: my_resource
     """
     result = dict(comment=[], ret=[], result=True)
     ret = await hub.tool.aws.ec2.vpc.search_raw(
@@ -101,7 +150,7 @@ async def list_(
     for vpc in ret["ret"]["Vpcs"]:
         vpc_id = vpc.get("VpcId")
         result["ret"].append(
-            await hub.tool.aws.ec2.conversion_utils.convert_raw_vpc_to_present(
+            await hub.tool.aws.ec2.conversion_utils.convert_raw_vpc_to_present_async(
                 ctx, raw_resource=vpc, idem_resource_name=vpc_id
             )
         )
