@@ -88,9 +88,7 @@ async def get(
         return result
     policy["Document"] = ret_get_policy_version["ret"]["PolicyVersion"].get("Document")
 
-    result[
-        "ret"
-    ] = await hub.tool.aws.iam.conversion_utils.convert_raw_policy_to_present(
+    result["ret"] = hub.tool.aws.iam.conversion_utils.convert_raw_policy_to_present(
         ctx, raw_resource=policy
     )
 
