@@ -45,7 +45,9 @@ async def get(
         )
         return result
 
-    result["ret"] = await hub.tool.aws.kms.conversion_utils.convert_raw_key_to_present(
+    result[
+        "ret"
+    ] = await hub.tool.aws.kms.conversion_utils.convert_raw_key_to_present_async(
         ctx, raw_resource=ret["ret"]["KeyMetadata"]
     )
     return result
@@ -87,7 +89,7 @@ async def list_(
 
         try:
             result["ret"].append(
-                await hub.tool.aws.kms.conversion_utils.convert_raw_key_to_present(
+                await hub.tool.aws.kms.conversion_utils.convert_raw_key_to_present_async(
                     ctx, raw_resource=key_details["ret"]["KeyMetadata"]
                 )
             )
