@@ -82,6 +82,7 @@ async def list_(
     private_zone: bool = None,
     vpc_id: str = None,
     tags: Dict[str, Any] = None,
+    resource_id: str = None,
 ):
     """
     Args:
@@ -97,6 +98,9 @@ async def list_(
         tags(dict, Optional):
             Tags of the hosted_zone. One of the filter option for hosted_zone
 
+        resource_id(str, Optional):
+            AWS Hosted Zone id to identify the resource.
+
     Returns:
         Dict[bool, list, dict or None]:
 
@@ -121,6 +125,17 @@ async def list_(
     result = dict(comment=[], ret=None, result=True)
 
     hosted_zones = []
+
+    # Even though this is list a resource_id might be specified
+    if resource_id:
+        get_ret = await hub.exec.aws.route53.hosted_zone.get(
+            ctx, name="from-list", resource_id=resource_id
+        )
+        if get_ret["result"] and get_ret["ret"]:
+            result["ret"] = [get_ret["ret"]]
+            return result
+        return get_ret
+
     ret = await hub.tool.aws.route53.hosted_zone_utils.get_all_hosted_zones(ctx)
     if not ret["result"]:
         result["result"] = ret["result"]
