@@ -11,6 +11,24 @@ async def get(hub, ctx, name: str, resource_id: str) -> Dict:
 
         resource_id(str):
             AWS S3 bucket name.
+
+    Examples:
+        Calling from the CLI:
+
+        .. code-block:: bash
+
+            $ idem exec aws.s3.bucket_lifecycle.get name="bucket-name" resource_id="bucket-id"
+
+        Using in a state:
+
+        .. code-block:: yaml
+
+            get_a_bucket:
+              exec.run:
+                - path: aws.s3.bucket.get
+                - kwargs:
+                   name: bucket-name
+                   resource_id: bucket-id
     """
     result = dict(comment=[], ret=None, result=True)
     ret = await hub.exec.boto3.client.s3.get_bucket_lifecycle_configuration(
