@@ -418,7 +418,9 @@ async def present(
                     Certificate=certificate,
                     PrivateKey=private_key,
                     CertificateChain=certificate_chain,
-                    Tags=hub.tool.aws.tag_utils.convert_tag_dict_to_list(tags),
+                    Tags=hub.tool.aws.tag_utils.convert_tag_dict_to_list(tags)
+                    if tags
+                    else None,
                 )
                 result["result"] = imported["result"]
                 if not result["result"]:
@@ -493,7 +495,9 @@ async def present(
                     DomainValidationOptions=domain_validation_options,
                     Options=options,
                     CertificateAuthorityArn=certificate_authority_arn,
-                    Tags=hub.tool.aws.tag_utils.convert_tag_dict_to_list(tags),
+                    Tags=hub.tool.aws.tag_utils.convert_tag_dict_to_list(tags)
+                    if tags
+                    else None,
                 )
                 result["result"] = requested["result"]
                 if not result["result"]:
@@ -522,6 +526,7 @@ async def present(
                     certificate_waiter,
                     CertificateArn=resource_id,
                     WaiterConfig=waiter_config,
+                    delay=30,
                 )
 
                 result["comment"] = result[
@@ -700,42 +705,3 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
         }
 
     return result
-
-
-def is_pending(hub, ret):
-    """Reconciliation is_pending plugin for ACM certificates."""
-    new_state = ret.get("new_state", None)
-    resource_id = new_state.get("resource_id") if new_state else None
-    status = None
-    state_list = []
-    if new_state:
-        domain_validation_options_validation = new_state.get(
-            "domain_validation_options_validation"
-        )
-        for domain_validation_option in domain_validation_options_validation:
-            status = domain_validation_option.get("validation_status")
-            if not status:
-                hub.log.debug(
-                    f"Asynchronous ACM service domain validation assignment not complete, need to retry {new_state}"
-                )
-                return True
-            elif status and isinstance(status, str):
-                hub.log.debug(
-                    f"ACM certificate {resource_id} is_pending() status {status}"
-                )
-                if status.casefold() == "success" or status.casefold() == "failed":
-                    hub.log.debug(
-                        f"No need to reconcile new state {new_state} with status {status}"
-                    )
-                    state_list.append(False)
-                if status.casefold() == "pending_validation":
-                    hub.log.debug(
-                        f"Reconcile new state {new_state} with status {status}"
-                    )
-                    state_list.append(True)
-            resource_record = domain_validation_option.get("resource_record")
-            if not resource_record:
-                state_list.append(True)
-        # Returns true if any of the domain validation options need to be reconciled
-        return any(state_list)
-    return (not ret["result"]) or (bool(ret["changes"]))
