@@ -329,7 +329,7 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
 
             for deployment in get_deployments_ret["ret"]["items"]:
                 resource_id = deployment.get("id")
-                resource_translated = await hub.tool.aws.apigateway.deployment.convert_raw_deployment_to_present(
+                resource_translated = hub.tool.aws.apigateway.deployment.convert_raw_deployment_to_present(
                     raw_resource=deployment,
                     resource_id=resource_id,
                     rest_api_id=rest_api_id,
