@@ -347,43 +347,3 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
         }
 
     return result
-
-
-async def search(hub, ctx, name, resource_id: str) -> Dict[str, Any]:
-    """Use an un-managed API Gateway v2 api resource as a data-source. This function has been deprecated.
-
-    Please use exec.run with aws.apigatewayv2.api.get instead.
-
-    Args:
-        name(str): An Idem name of the resource.
-        resource_id(str): The API resource identifier in Amazon Web Services.
-
-    Request syntax:
-        [idem_test_aws_apigatewayv2_api]:
-          aws.apigatewayv2.api.search:
-            - resource_id: 'string'
-
-    Returns:
-        Dict[str, Any]
-
-    Examples:
-        .. code-block:: sls
-
-            idem_test_aws_apigatewayv2_api:
-              aws.apigatewayv2.api.search:
-                - resource_id: value
-    """
-    hub.log.warning(
-        f"aws.apigatewayv2.api.search '{name}' state has been deprecated. Please use exec.run with aws.apigatewayv2.api.get instead."
-    )
-    result = dict(comment=[], old_state=None, new_state=None, name=name, result=True)
-    ret = await hub.exec.aws.apigatewayv2.api.get(
-        ctx=ctx, name=name, resource_id=resource_id
-    )
-    result["result"] = ret["result"]
-    result["comment"] = ret["comment"]
-    if result["result"]:
-        result["old_state"] = ret["ret"]
-        # Populate both "old_state" and "new_state" with the same data
-        result["new_state"] = copy.deepcopy(result["old_state"])
-    return result
