@@ -1036,6 +1036,39 @@ async def present(
                   propagate_at_launch-Name: false
     """
     result = dict(comment=(), old_state=None, new_state=None, name=name, result=True)
+    if launch_template and "Version" in launch_template:
+        launch_template["Version"] = str(launch_template["Version"])
+
+    if mixed_instances_policy:
+        # Version field of LaunchTemplateSpecification should be string, but idem is considering it as int
+        # while passing through sls, so handling the Version field accordingly.
+
+        template = mixed_instances_policy.get("LaunchTemplate", {})
+        launch_template_specification = template.get("LaunchTemplateSpecification", {})
+        if launch_template_specification and "Version" in launch_template_specification:
+            launch_template_specification["Version"] = str(
+                launch_template_specification["Version"]
+            )
+
+        overrides = template.get("Overrides", [])
+        for item in overrides:
+            lts = item.get("LaunchTemplateSpecification", {})
+            if lts and "Version" in lts:
+                lts["Version"] = str(lts["Version"])
+
+    if launch_configuration_name == "":
+        launch_configuration_name = None
+
+    if (
+        not launch_template
+        and not launch_configuration_name
+        and not mixed_instances_policy
+    ):
+        result["comment"] = (
+            "Either launch_template or launch_configuration_name or mixed_instances_policy must be provided",
+        )
+        result["result"] = False
+        return result
 
     # Query for auto scaling groups
     auto_scaling_group = None
@@ -1091,8 +1124,12 @@ async def present(
         "desired_capacity_type": desired_capacity_type,
     }
 
+    desired_state = hub.tool.aws.state_utils.merge_arguments(
+        desire_state=copy.deepcopy(desired_state), current_state=current_state
+    )
+
     is_auto_scaling_group_updated = (
-        hub.tool.aws.autoscaling.auto_scaling_group_utils.is_auto_scaling_group_updated(
+        hub.tool.aws.autoscaling.auto_scaling_group_utils.is_update_required(
             current_state=current_state, desired_state=desired_state
         )
     )
@@ -1116,6 +1153,8 @@ async def present(
             enforced_state=current_state,
             desired_state=desired_state,
         )
+        result["new_state"]["launch_configuration_name"] = launch_configuration_name
+        result["new_state"]["launch_template"] = launch_template
         result["comment"] = (
             hub.tool.aws.comment_utils.would_update_comment(
                 resource_type="aws.autoscaling.auto_scaling_group", name=name
