@@ -64,7 +64,7 @@ async def present(
     ] = None,
     resource_id: str = None,
 ) -> Dict[str, Any]:
-    r"""Creates an AWS Budget Action with the requested name and rules.
+    """Creates an AWS Budget Action with the requested name and rules.
 
     Args:
         name(str):
@@ -401,7 +401,7 @@ async def absent(
 
 
 async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
-    r"""Lists the AWS Budget Actions.
+    """Lists the AWS Budget Actions.
 
     Describe the resource in a way that can be recreated/managed with the corresponding "present" function.
 
