@@ -36,7 +36,7 @@ async def present(
         )
     ] = None,
 ) -> Dict[str, Any]:
-    r"""Allocates an Elastic IP address to your Amazon Web Services account.
+    """Allocates an Elastic IP address to your Amazon Web Services account.
 
     After you allocate the Elastic IP address you can associate it with an instance or network interface. After you release an Elastic IP address,
     it is released to the IP address pool and can be allocated to a different Amazon Web Services account. [EC2-VPC]
@@ -215,7 +215,7 @@ async def present(
 
 
 async def absent(hub, ctx, name: str, resource_id: str = None) -> Dict[str, Any]:
-    r"""Releases the specified Elastic IP address.
+    """Releases the specified Elastic IP address.
 
     [EC2-Classic, default VPC] Releasing an Elastic IP address automatically disassociates it from any instance that
     it's associated with. To disassociate an Elastic IP address without releasing it, use DisassociateAddress .
@@ -306,7 +306,7 @@ async def absent(hub, ctx, name: str, resource_id: str = None) -> Dict[str, Any]
 
 
 async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
-    r"""
+    """
     Describe the resource in a way that can be recreated/managed with the corresponding "present" function.
 
     Describes the specified Elastic IP addresses or all of your Elastic IP addresses.
