@@ -49,7 +49,7 @@ async def present(
         )
     ] = None,
 ) -> Dict[str, Any]:
-    r"""Creates a flow log to capture information about IP traffic for a specific network interface, subnet,
+    """Creates a flow log to capture information about IP traffic for a specific network interface, subnet,
     or VPC.
 
     Flow log data for a monitored network interface is recorded as flow log records, which are log events
@@ -243,7 +243,7 @@ async def present(
 
 
 async def absent(hub, ctx, name: str, resource_id: str = None) -> Dict[str, Any]:
-    r"""Deletes a flow log.
+    """Deletes a flow log.
 
     Args:
         name(str): Name of the resource.
@@ -316,7 +316,7 @@ async def absent(hub, ctx, name: str, resource_id: str = None) -> Dict[str, Any]
 
 
 async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
-    r"""
+    """
     Describe the resource in a way that can be recreated/managed with the corresponding "present" function
 
     Describes one or more flow logs. To view the information in your flow logs (the log streams for the network
