@@ -5,6 +5,8 @@ from typing import Any
 from typing import Dict
 from typing import List
 
+from dict_tools.typing import Computed
+
 __contracts__ = ["resource", "allow_sync_sls_name_and_name_tag"]
 __reconcile_wait__ = {"static": {"wait_in_seconds": 5}}
 
@@ -40,6 +42,10 @@ async def present(
                 ("device_index", int),
                 ("network_interface_id", str, field(default=None)),
                 ("network_card_index", int, field(default=None)),
+                ("subnet_id", Computed[str], field(default=None)),
+                ("public_ip_address", Computed[str], field(default=None)),
+                ("private_ip_address", Computed[str], field(default=None)),
+                ("mac_address", Computed[str], field(default=None)),
             ],
         )
     ] = None,
@@ -80,7 +86,6 @@ async def present(
     nitro_enclave_enabled: bool = None,
     # Can only be changed on initial creation of an instance as far as we know so far
     client_token: str = None,
-    root_device_name: str = None,
     product_codes: List[Dict[str, str]] = None,
     reservation_id: str = None,
     block_device_mappings: List[
@@ -89,7 +94,11 @@ async def present(
             [
                 ("device_name", str),
                 ("volume_id", str, field(default=None)),
-                ("delete_on_termination", str, field(default=False)),
+                ("delete_on_termination", bool, field(default=False)),
+                # computed volume properties
+                ("size", Computed[int], field(default=None)),
+                ("type", Computed[str], field(default=None)),
+                ("encrypted", Computed[bool], field(default=None)),
             ],
         )
     ] = None,
@@ -120,6 +129,10 @@ async def present(
     # Capacity Reservation Options
     capacity_reservation_preference: str = None,
     instance_requirements: Dict[str, Any] = None,
+    # computed properties
+    instance_state: Computed[str] = None,
+    public_ip_address: Computed[str] = None,
+    root_device_name: Computed[str] = None,
     # idem-heist options
     bootstrap: List[Dict[str, str]] = None,
     **kwargs,
@@ -198,6 +211,18 @@ async def present(
                 can’t specify the network card index when using this API. To specify the network card index, use
                 RunInstances.
 
+            * subnet_id (Computed[str]):
+                The ID of the subnet.
+
+            * public_ip_address (Computed[str]):
+                The public IP address or Elastic IP address bound to the network interface.
+
+            * private_ip_address (Computed[str]):
+                The IPv4 address of the network interface within the subnet.
+
+            * mac_address (Computed[str]):
+                The MAC address.
+
         monitoring_enabled(bool, Optional):
             Indicates whether detailed monitoring is enabled.
 
@@ -407,6 +432,14 @@ async def present(
             The attributes for the instance type. When you specify instance attributes, Amazon EC2 will identify
             instance types with these attributes.
 
+        instance_state(Computed[str]):
+            The reported state of the instance, possible values are:
+            pending, running, shutting-down, terminated, stopping, stopped
+
+        public_ip_address(Computed[str]):
+            The public IPv4 address, or the Carrier IP address assigned to the instance, if applicable.
+            A Carrier IP address only applies to an instance launched in a subnet associated with a Wavelength Zone.
+
         bootstrap(list[dict[str, Any]], Optional):
             Bootstr options for provisioning an instance with "heist".
 
@@ -713,8 +746,6 @@ async def present(
                 new_bd = dict(DeviceName=device_name, NoDevice="")
                 if bd.get("virtual_name"):
                     new_bd["VirtualName"] = bd["virtual_name"]
-                if bd.get("delete_on_termination"):
-                    new_bd["DeleteOnTermination"] = bd["delete_on_termination"]
                 new_block_device_mappings.append(new_bd)
 
         # Create a brand new instance with minimal arguments, it will be updated after creation
@@ -767,7 +798,7 @@ async def present(
 
         result["comment"] += [f"Created '{name}'"]
         resource_id = create_ret.ret["Instances"][0]["InstanceId"]
-        # This makes sure the created VPC is saved to esm regardless if the subsequent update call fails or not.
+        # This makes sure the created Instance is saved to esm regardless if the subsequent update call fails or not.
         result["new_state"] = dict(name=name, resource_id=resource_id)
         result["force_save"] = True
 
@@ -787,37 +818,39 @@ async def present(
 
     # Modify all the attributes that need modification
     if ctx.test:
-        if running:
-            desired_state["instance_state"] = "running"
-        else:
-            desired_state["instance_state"] = "stopped"
-
         result["new_state"] = hub.tool.aws.ec2.instance.state.test(**desired_state)
-    else:
-        resource = await hub.tool.boto3.resource.create(
-            ctx, "ec2", "Instance", id=resource_id
-        )
-        result["result"] &= await hub.tool.aws.ec2.instance.update.init.apply(
-            ctx,
-            resource,
-            old_value=current_state,
-            new_value=desired_state,
-            comments=result["comment"],
-        )
+        return result
 
-        get = await hub.exec.aws.ec2.instance.get(
-            ctx, resource_id=resource_id, name=name
-        )
+    resource = await hub.tool.boto3.resource.create(
+        ctx, "ec2", "Instance", id=resource_id
+    )
+
+    # TODO: Remove waiters across the board in this flow
+    if resource.state["Name"] == "pending":
+        await hub.tool.boto3.resource.exec(resource, "wait_until_running")
+    elif resource.state["Name"] == "stopping":
+        await hub.tool.boto3.resource.exec(resource, "wait_until_stopped")
+
+    result["result"] &= await hub.tool.aws.ec2.instance.update.init.apply(
+        ctx,
+        resource,
+        old_value=current_state,
+        new_value=desired_state,
+        comments=result["comment"],
+    )
+
+    get = await hub.exec.aws.ec2.instance.get(ctx, resource_id=resource_id, name=name)
+    if get.result:
         current_state = get.ret
-        result["new_state"] = current_state
+    result["new_state"] = current_state
 
-        if running:
-            # If running is set to True then it goes to reconciler and makes sure current state is running
-            hub.log.debug(f"Waiting for instance '{resource_id}' to be running")
-            result["rerun_data"] = dict(target_instance_state="running")
-        else:
-            hub.log.debug(f"Waiting for instance '{resource_id}' to be stopped")
-            result["rerun_data"] = dict(target_instance_state="stopped")
+    if running:
+        # If running is set to True then it goes to reconciler and makes sure current state is running
+        hub.log.debug(f"Waiting for instance '{resource_id}' to be running")
+        result["rerun_data"] = dict(target_instance_state="running")
+    else:
+        hub.log.debug(f"Waiting for instance '{resource_id}' to be stopped")
+        result["rerun_data"] = dict(target_instance_state="stopped")
 
     return result
 
