@@ -1134,7 +1134,7 @@ async def present(
             )
             result["result"] = result["result"] and update_ret["result"]
             result["comment"] = update_ret["comment"]
-            resource_updated = resource_updated or bool(update_ret["ret"])
+            resource_updated = resource_updated or bool(update_ret["result"])
             if ctx.get("test", False) and update_ret["result"]:
                 plan_state["tags"] = update_ret["ret"]
         update_version_ret = (
@@ -1147,7 +1147,7 @@ async def present(
                 new_launch_template_data=launch_template_data,
             )
         )
-        if ctx.get("test", False) and update_version_ret["result"]:
+        if ctx.get("test", False) and update_version_ret["ret"]:
             plan_state["launch_template_data"] = update_version_ret["ret"]
         result["comment"] = result["comment"] + update_version_ret["comment"]
         resource_updated = resource_updated or bool(update_version_ret["ret"])
@@ -1181,12 +1181,14 @@ async def present(
             DryRun=dry_run,
             LaunchTemplateName=name,
             VersionDescription=version_description,
-            LaunchTemplateData=launch_template_data,
+            LaunchTemplateData=hub.tool.aws.ec2.launch_template.pre_process_launch_template_data(
+                chunk=launch_template_data
+            ),
             TagSpecifications=(
                 [
                     {
                         "ResourceType": "launch-template",
-                        "Tags": hub.tool.aws.tag_utils.convert_tag_dict_to_list(tags),
+                        "Tags": tags,
                     }
                 ]
                 if tags
