@@ -100,7 +100,7 @@ async def present(
 
         if tags is not None and tags != old_tags:
             group_id = before["ret"]["group_id"]
-            update_ret = await hub.exec.aws.ec2.tag.update_tags(
+            update_ret = await hub.tool.aws.ec2.tag.update_tags(
                 ctx,
                 resource_id=group_id,
                 old_tags=old_tags,
