@@ -19,7 +19,7 @@ from typing import Any
 from typing import Dict
 from typing import List
 
-__contracts__ = ["resource"]
+__contracts__ = ["resource", "allow_sync_sls_name_and_name_tag"]
 
 TREQ = {
     "present": {"require": ["aws.ec2.vpc.present"]},
