@@ -154,24 +154,27 @@ async def present(
                 - description: 'Security group desc'
     """
 
-    result = dict(comment=(), old_state=None, new_state=None, name=name, result=True)
+    result = {
+        "comment": (),
+        "old_state": None,
+        "new_state": None,
+        "name": name,
+        "result": True,
+    }
     before = None
     resource_updated = False
     if resource_id:
-        before = await hub.exec.boto3.client.ec2.describe_security_group_rules(
-            ctx, SecurityGroupRuleIds=[resource_id]
-        )
-    if before and before["result"] and before["ret"]["SecurityGroupRules"]:
-        result[
-            "old_state"
-        ] = hub.tool.aws.ec2.conversion_utils.convert_raw_sg_rule_to_present(
-            raw_resource=before["ret"]["SecurityGroupRules"][0], idem_resource_name=name
+        before = await hub.exec.aws.ec2.security_group_rule.get(
+            ctx,
+            resource_id=resource_id,
         )
+    if before and before["result"] and before["ret"]:
+        result["old_state"] = before["ret"]
         plan_state = copy.deepcopy(result["old_state"])
         update_ret = (
             await hub.tool.aws.ec2.security_group_rule.update_security_group_rule(
                 ctx,
-                before=before["ret"]["SecurityGroupRules"][0],
+                before=before["ret"],
                 cidr_ipv4=cidr_ipv4,
                 cidr_ipv6=cidr_ipv6,
                 description=description,
@@ -305,16 +308,11 @@ async def present(
         if ctx.get("test", False):
             result["new_state"] = plan_state
         elif (not before) or resource_updated:
-            after = await hub.exec.boto3.client.ec2.describe_security_group_rules(
+            after = await hub.exec.aws.ec2.security_group_rule.get(
                 ctx,
-                SecurityGroupRuleIds=[resource_id],
-            )
-            result[
-                "new_state"
-            ] = hub.tool.aws.ec2.conversion_utils.convert_raw_sg_rule_to_present(
-                raw_resource=after["ret"]["SecurityGroupRules"][0],
-                idem_resource_name=name,
+                resource_id=resource_id,
             )
+            result["new_state"] = after["ret"]
         else:
             result["new_state"] = copy.deepcopy(result["old_state"])
     except Exception as e:
