@@ -347,82 +347,3 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
         }
 
     return result
-
-
-async def search(
-    hub, ctx, name, resource_id: str, registry_id: str = None, default: bool = None
-) -> Dict[str, Any]:
-    """Use an un-managed AWS ECR repository as a data-source.
-
-    Args:
-        name(str):
-            An Idem name of the resource.
-        resource_id(str):
-            The name of the ECR repository in Amazon Web Services.
-        registry_id(str, Optional):
-            The Amazon Web Services account ID associated with the registry that contains the repository
-            to search. If you do not specify a registry, the default registry is assumed.
-
-    Request syntax:
-      .. code-block:: sls
-
-        [idem_test_aws_ecr_repository]:
-          aws.ecr.repository.search:
-            - name: 'string'
-            - resource_id: 'string'
-            - registry_id: 'string'
-
-    Returns:
-        Dict[str, Any]
-
-    Examples:
-        .. code-block:: sls
-
-            idem_test_aws_ecr_repository:
-              aws.ecr.repository.search:
-                - name: idem_test_ecr_repository
-                - resource_id: idem_test_ecr_repository
-                - registry_id: idem_test_ecr_registry
-    """
-    hub.log.warning(
-        f"aws.ecr.repository.search '{name}' state has been deprecated. Please use exec.run with aws.ecr.repository.get instead."
-    )
-    result = dict(comment=(), old_state=None, new_state=None, name=name, result=True)
-
-    describe_ret = await hub.exec.boto3.client.ecr.describe_repositories(
-        ctx, repositoryNames=[resource_id], registryId=registry_id
-    )
-    if not describe_ret["result"]:
-        result["result"] = False
-        result["comment"] = (
-            f"Unable to find aws.ecr.repository resource with repository name '{resource_id}'",
-        )
-        return result
-
-    if len(describe_ret["ret"].get("repositories")) > 1:
-        result["result"] = False
-        result["comment"] = (
-            f"More than one aws.ecr.repository resource with name '{resource_id}' was found",
-        )
-        return result
-
-    repository = describe_ret["ret"].get("repositories")[0]
-
-    tags_ret = await hub.exec.boto3.client.ecr.list_tags_for_resource(
-        ctx, resourceArn=repository.get("repositoryArn")
-    )
-    if not tags_ret["result"]:
-        result["result"] = False
-        result["comment"] = tags_ret["comment"]
-        return result
-
-    result[
-        "old_state"
-    ] = hub.tool.aws.ecr.conversion_utils.convert_raw_repository_to_present(
-        raw_resource=repository,
-        tags=tags_ret.get("ret").get("tags") if tags_ret.get("result") else None,
-        idem_resource_name=name,
-    )
-    result["new_state"] = copy.deepcopy(result["old_state"])
-
-    return result
