@@ -297,7 +297,7 @@ async def absent(
     preserve: bool = False,
     timeout: Dict = None,
 ) -> Dict[str, Any]:
-    r"""
+    """
     Delete an Amazon EKS add-on.
 
     When you remove the add-on, it will also be deleted from the cluster. You can always manually start an add-on on the
@@ -314,7 +314,7 @@ async def absent(
         resource_id(str, Optional):
             AWS EKS addon name. Idem automatically considers this resource being absent if this field is not specified.
 
-        preserve(Boolean, Optional):
+        preserve(bool, Optional):
             Specifying this option preserves the add-on software on your cluster but Amazon EKS stops managing any
             settings for the add-on. If an IAM account is associated with the add-on, it is not removed.
 
@@ -333,7 +333,7 @@ async def absent(
               aws.eks.addon.absent:
                 - cluster_name: 'string'
                 - resource_id: 'string'
-                - preserve: boolean
+                - preserve: bool
 
     Returns:
         Dict[str, Any]
@@ -417,7 +417,7 @@ async def absent(
 
 
 async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
-    r"""
+    """
     Describe the resource in a way that can be recreated/managed with the corresponding "present" function
 
     Lists the available add-ons.
