@@ -290,7 +290,7 @@ async def present(
                 - release_version: "string"
                 - resource_id: "string"
                 - status: "string"
-                - capacity_type: "ON_DEMAND" | "SPOT"
+                - capacity_type: "ON_DEMAND|SPOT"
                 - instance_types:
                   - string
                 - subnets:
@@ -516,7 +516,7 @@ async def absent(
     resource_id: str = None,
     timeout: Dict = None,
 ) -> Dict[str, Any]:
-    r"""
+    """
     **Autogenerated function**
 
     Deletes an Amazon EKS node group for a cluster.
