@@ -45,21 +45,24 @@ async def present(
     You get all of this information from the OIDC IdP you want to use to access Amazon Web Services.
 
     Args:
-        name(str): The idem name for IAM OIDC provider.
+        name(str):
+            The idem name for IAM OIDC provider.
 
-        url(str): The URL of the identity provider. The URL must begin with https:// and should correspond to the iss
-            claim in the provider's OpenID Connect ID tokens. Per the OIDC standard, path components are allowed but
-            query parameters are not. Typically the URL consists of only a hostname, like https://server.example.org or
+        url(str):
+            The URL of the identity provider. The URL must begin with https:// and should correspond to the iss claim
+            in the provider's OpenID Connect ID tokens. Per the OIDC standard, path components are allowed but query
+            parameters are not. Typically the URL consists of only a hostname, like https://server.example.org or
             https://example.com . The URL should not contain a port number.
 
             You cannot register the same provider multiple times in a single Amazon Web Services account. If you try to
             submit a URL that has already been used for an OpenID Connect provider in the Amazon Web Services account,
             you will get an error.
 
-        thumbprint_list(List): A list of server certificate thumbprints for the OpenID Connect (OIDC) identity
-            provider's server certificates. Typically this list includes only one entry. However, IAM lets you have up
-            to five thumbprints for an OIDC provider. This lets you maintain multiple thumbprints if the identity
-            provider is rotating certificates.
+        thumbprint_list(List):
+            A list of server certificate thumbprints for the OpenID Connect (OIDC) identity provider's server
+            certificates. Typically this list includes only one entry. However, IAM lets you have up to five
+            thumbprints for an OIDC provider. This lets you maintain multiple thumbprints if the identity provider is
+            rotating certificates.
 
             The server certificate thumbprint is the hex-encoded SHA-1 hash value of the X.509 certificate used by the
             domain where the OpenID Connect provider makes its keys available. It is always a 40-character string.
@@ -79,11 +82,13 @@ async def present(
                 self-signed X.509 certificate. This thumbprint is used by the domain where the OpenID Connect provider
                 makes its keys available. The thumbprint is always a 40-character string.
 
-        resource_id(str, Optional): The Amazon Resource Name (ARN) of the IAM OpenID Connect provider resource object.
+        resource_id(str, Optional):
+            The Amazon Resource Name (ARN) of the IAM OpenID Connect provider resource object.
 
-        client_id_list(List, Optional): Provides a list of client IDs, also known as audiences. When a mobile or web
-            app registers with an OpenID Connect provider, they establish a value that identifies the application. This
-            is the value that's sent as the client_id parameter on OAuth requests.
+        client_id_list(List, Optional):
+            Provides a list of client IDs, also known as audiences. When a mobile or web app registers with an OpenID
+            Connect provider, they establish a value that identifies the application. This is the value that's sent as
+            the client_id parameter on OAuth requests.
 
             You can register multiple client IDs with the same provider. For example, you might have multiple
             applications that use the same OIDC provider. You cannot register more than 100 client IDs with a single
@@ -92,18 +97,21 @@ async def present(
             There is no defined format for a client ID. The CreateOpenIDConnectProviderRequest operation accepts
             client IDs up to 255 characters long.
 
-        tags(Dict or List, Optional): Dict in the format of {tag-key: tag-value} or List of tags in the format of
-            [{"Key": tag-key, "Value": tag-value}] to associate with the IAM OpenID Connect (OIDC) provider.
-            Each tag consists of a key name and an associated value. Defaults to None.
+        tags(Dict or List, Optional):
+            Dict in the format of {tag-key: tag-value} or List of tags in the format of [{"Key": tag-key, "Value":
+            tag-value}] to associate with the IAM OpenID Connect (OIDC) provider.  Each tag consists of a key name and
+            an associated value. Defaults to None.
+
             * (Key): The key name that can be used to look up or retrieve the associated value. For example,
                 Department or Cost Center are common choices.
+
             * (Value): The value associated with this tag. For example, tags with a key name of Department could have
-                values such as Human Resources, Accounting, and Support. Tags with a key name of Cost Center
-                might have values that consist of the number associated with the different cost centers in your
-                company. Typically, many resources have tags with the same key name but with different values.
-                Amazon Web Services always interprets the tag Value as a single string. If you need to store an
-                array, you can store comma-separated values in the string. However, you must interpret the value
-                in your code.
+                values such as Human Resources, Accounting, and Support. Tags with a key name of Cost Center might have
+                values that consist of the number associated with the different cost centers in your company.
+                Typically, many resources have tags with the same key name but with different values.  Amazon Web
+                Services always interprets the tag Value as a single string. If you need to store an array, you can
+                store comma-separated values in the string. However, you must interpret the value in your code.
+
     Request Syntax:
         [oidc-resource-name]:
           aws.iam.open_id_connect_provider.present:
@@ -299,8 +307,11 @@ async def absent(hub, ctx, name: str, resource_id: str = None) -> Dict[str, Any]
     trust policies. Any attempt to assume a role that references a deleted provider fails.
 
     Args:
-        name(str): The idem name for IAM OIDC provider.
-        resource_id(str): The Amazon Resource Name (ARN) of the IAM OpenID Connect provider resource object to delete.
+        name(str):
+            The idem name for IAM OIDC provider.
+
+        resource_id(str):
+            The Amazon Resource Name (ARN) of the IAM OpenID Connect provider resource object to delete.
 
     Request Syntax:
         [oidc-resource-id]:
@@ -371,6 +382,9 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
 
     Gets information about the AWS IAM OpenID Connect provider
 
+    Args:
+        None
+
     Returns:
         Dict[str, Any]
 
