@@ -25,33 +25,33 @@ async def present(
     Args:
         name(str): An Idem name of the resource.
 
-        minimum_password_length(int, optional): The minimum number of characters allowed in an IAM user password.
+        minimum_password_length(int, Optional): The minimum number of characters allowed in an IAM user password.
             If you do not specify a value for this parameter, then the operation uses the default value of 6.
 
-        require_symbols(bool, optional): Specifies whether IAM user passwords must contain at least one of the following non-alphanumeric characters:
+        require_symbols(bool, Optional): Specifies whether IAM user passwords must contain at least one of the following non-alphanumeric characters:
             ! @ # $ % ^ & * ( ) _ + - = [ ] { } | '
             If you do not specify a value for this parameter, then the operation uses the default value of false.
             The result is that passwords do not require at least one symbol character.
 
-        require_numbers(bool, optional): Specifies whether IAM user passwords must contain at least one numeric character (0 to 9).
+        require_numbers(bool, Optional): Specifies whether IAM user passwords must contain at least one numeric character (0 to 9).
             If you do not specify a value for this parameter, then the operation uses the default value of false. The result is that passwords do not require at least one numeric character.
 
-        require_uppercase_characters(bool, optional): Specifies whether IAM user passwords must contain at least one uppercase character from the ISO basic Latin alphabet (A to Z).
+        require_uppercase_characters(bool, Optional): Specifies whether IAM user passwords must contain at least one uppercase character from the ISO basic Latin alphabet (A to Z).
             If you do not specify a value for this parameter, then the operation uses the default value of false. The result is that passwords do not require at least one uppercase character.
 
-        require_lowercase_characters(bool, optional): Specifies whether IAM user passwords must contain at least one lowercase character from the ISO basic Latin alphabet (a to z).
+        require_lowercase_characters(bool, Optional): Specifies whether IAM user passwords must contain at least one lowercase character from the ISO basic Latin alphabet (a to z).
             If you do not specify a value for this parameter, then the operation uses the default value of false. The result is that passwords do not require at least one lowercase character.
 
-        allow_users_to_change_password(bool, optional): Allows all IAM users in your account to use the Amazon Web Services Management Console to change their own passwords. For more information, see Permitting IAM users to change their own passwords in the IAM User Guide .
+        allow_users_to_change_password(bool, Optional): Allows all IAM users in your account to use the Amazon Web Services Management Console to change their own passwords. For more information, see Permitting IAM users to change their own passwords in the IAM User Guide .
             If you do not specify a value for this parameter, then the operation uses the default value of false. The result is that IAM users in the account do not automatically have permissions to change their own password.
 
-        max_password_age(int, optional): The number of days that an IAM user password is valid.
+        max_password_age(int, Optional): The number of days that an IAM user password is valid.
             If you do not specify a value for this parameter, then the operation uses the default value of 0. The result is that IAM user passwords never expire.
 
-        password_reuse_prevention(int, optional): Specifies the number of previous passwords that IAM users are prevented from reusing.
+        password_reuse_prevention(int, Optional): Specifies the number of previous passwords that IAM users are prevented from reusing.
             If you do not specify a value for this parameter, then the operation uses the default value of 0. The result is that IAM users are not prevented from reusing previous passwords.
 
-        hard_expiry(bool, optional): Prevents IAM users who are accessing the account via the Amazon Web Services Management Console from setting a new console password after their password has expired. The IAM user cannot access the console until an administrator resets the password.
+        hard_expiry(bool, Optional): Prevents IAM users who are accessing the account via the Amazon Web Services Management Console from setting a new console password after their password has expired. The IAM user cannot access the console until an administrator resets the password.
             If you do not specify a value for this parameter, then the operation uses the default value of false. The result is that IAM users can change their passwords after they expire and continue to sign in as the user.
 
     Request Syntax:
