@@ -39,12 +39,14 @@ async def present(
         description(str, Optional):
             A description of the KMS key.
         key_usage(str, Optional):
-            Determines the cryptographic operations for which you can use the KMS key. The default value is ``ENCRYPT_DECRYPT``.
+            Determines the cryptographic operations for which you can use the KMS key.
+            The default value is ``ENCRYPT_DECRYPT``.
             Valid values are ``ENCRYPT_DECRYPT``, ``GENERATE_VERIFY_MAC``, ``SIGN_VERIFY``.
         key_spec(str, Optional):
             Specifies the type of KMS key to create. The default value is ``SYMMETRIC_DEFAULT``.
-            Valid values are ``SYMMETRIC_DEFAULT``, ``HMAC_224``, ``HMAC_256``, ``HMAC_384``, ``HMAC_512``, ``RSA_2048``, ``RSA_3072``, ``RSA_4096``,
-            ``ECC_NIST_P256``, ``ECC_NIST_P384``, ``ECC_NIST_P521``, ``ECC_SECG_P256K1``, ``SM2``.
+            Valid values are ``SYMMETRIC_DEFAULT``, ``HMAC_224``, ``HMAC_256``, ``HMAC_384``, ``HMAC_512``,
+            ``RSA_2048``, ``RSA_3072``, ``RSA_4096``, ``ECC_NIST_P256``, ``ECC_NIST_P384``, ``ECC_NIST_P521``,
+            ``ECC_SECG_P256K1``, ``SM2``.
         key_state(str, Optional):
             Whether the key is enabled or not. The default value is ``Enabled``.
             Valid values are ``Enabled``, ``Disabled``.
@@ -52,9 +54,11 @@ async def present(
             The source of the key material for the KMS key. The default value is ``AWS_KMS``.
             Valid values are ``AWS_KMS``, ``EXTERNAL``, ``AWS_CLOUDHSM``.
         multi_region(bool, Optional):
-            Creates a multi-Region primary key that you can replicate into other Amazon Web Services Regions. Default value is ``False``.
+            Creates a multi-Region primary key that you can replicate into other Amazon Web Services Regions.
+            Default value is ``False``.
         policy(str, Optional):
-            The key policy to attach to the KMS key. If you do not specify a key policy, KMS attaches a default key policy to the KMS key.
+            The key policy to attach to the KMS key. If you do not specify a key policy,
+            KMS attaches a default key policy to the KMS key.
         bypass_policy_lockout_safety_check(bool, Optional):
             A flag to indicate whether to bypass the key policy lockout safety check. Default value is ``False``.
 
@@ -63,8 +67,8 @@ async def present(
               Do not set this value to ``True`` indiscriminately.
 
         enable_key_rotation(bool, Optional):
-            Whether to enable or disable automatic rotation of the key material of the specified symmetric encryption KMS key.
-            Default value is ``False``.
+            Whether to enable or disable automatic rotation of the key material of the specified symmetric
+            encryption KMS key. Default value is ``False``.
         tags(dict or list, Optional):
             Dict in the format of ``{tag-key: tag-value}`` or List of tags in the format of
             ``[{"TagKey": tag-key, "TagValue": tag-value}]`` to associate with the key.
@@ -94,7 +98,8 @@ async def present(
             - resource_id: 'string'
             - description: 'string'
             - key_usage: 'ENCRYPT_DECRYPT|GENERATE_VERIFY_MAC|SIGN_VERIFY'
-            - key_spec: 'SYMMETRIC_DEFAULT|HMAC_224|HMAC_256|HMAC_384|HMAC_512|RSA_2048|RSA_3072|RSA_4096|ECC_NIST_P256|ECC_NIST_P384|ECC_NIST_P521|ECC_SECG_P256K1|SM2'
+            - key_spec: 'SYMMETRIC_DEFAULT|HMAC_224|HMAC_256|HMAC_384|HMAC_512|RSA_2048|RSA_3072|RSA_4096|ECC_NIST_P256|
+                        ECC_NIST_P384|ECC_NIST_P521|ECC_SECG_P256K1|SM2'
             - key_state: 'Enabled|Disabled'
             - origin: 'AWS_KMS|EXTERNAL|AWS_CLOUDHSM'
             - multi_region: True|False
@@ -143,24 +148,23 @@ async def present(
 
     plan_state = {}
     updated_vals = {}
-    before = None
-    if resource_id is not None:
-        before = await hub.exec.aws.kms.key.get(ctx, name=name, resource_id=resource_id)
 
     if isinstance(tags, List):
         tags = hub.tool.aws.tag_utils.convert_tag_list_to_dict_tagkey(tags)
 
     policy = hub.tool.aws.state_comparison_utils.standardise_json(policy)
 
-    if before and before["result"]:
-        result["comment"] = (f"aws.kms.key '{name}' already exists.",)
-        try:
-            result["old_state"] = copy.deepcopy(before["ret"])
-        except Exception as e:
-            result["comment"] = result["comment"] + (str(e),)
+    if resource_id:
+        before = await hub.exec.aws.kms.key.get(ctx, name=name, resource_id=resource_id)
+        if not before["result"] or not before["ret"]:
             result["result"] = False
+            result["comment"] = before["comment"]
             return result
 
+        result["comment"] = hub.tool.aws.comment_utils.already_exists_comment(
+            resource_type="aws.kms.key", name=name
+        )
+        result["old_state"] = copy.deepcopy(before["ret"])
         # Used for 'test'
         plan_state = copy.deepcopy(result["old_state"])
 
@@ -188,9 +192,7 @@ async def present(
         old_state = result["old_state"].get("key_state", "")
         if key_state != old_state:
             if ctx.get("test", False):
-                result["comment"] = result["comment"] + (
-                    f"Would update state on aws.kms.key '{name}'.",
-                )
+                result["comment"] += (f"Would update state on aws.kms.key '{name}'.",)
                 plan_state["key_state"] = key_state
             else:
                 update_ret = None
@@ -267,7 +269,8 @@ async def present(
                         ] = bypass_policy_lockout_safety_check
                 else:
                     hub.log.warning(
-                        f"Failed to update the policy and/or bypass_policy_lockout_safety_check of aws.kms.key '{name}': {update_ret['comment']}"
+                        f"Failed to update the policy and/or bypass_policy_lockout_safety_check of "
+                        f"aws.kms.key '{name}': {update_ret['comment']}"
                     )
                     result["result"] = update_ret["result"]
                     result["comment"] = result["comment"] + update_ret["comment"]
@@ -355,7 +358,7 @@ async def present(
         result.get("old_state")
         and (
             key_state == "Enabled"
-            or (key_state == None and result["old_state"].get("key_state") == "Enabled")
+            or (key_state is None and result["old_state"].get("key_state") == "Enabled")
         )
         and enable_key_rotation != result["old_state"].get("enable_key_rotation", False)
     ):
@@ -404,9 +407,9 @@ async def absent(
     """Deletes an AWS KMS key.
 
     Key cannot be immediately deleted but can be scheduled to be deleted.
-    Once the key is set to be deleted in ``pending_window_in_days`` a deletion date is set on the key and it cannot be modified.
-    So deleting again with a different ``pending_window_in_days`` is ignored. Also key can be disabled using the "present" function
-    with ``key_state: 'Disabled'``.
+    Once the key is set to be deleted in ``pending_window_in_days`` a deletion date is set on the key and it cannot
+    be modified. So deleting again with a different ``pending_window_in_days`` is ignored. Also key can be disabled
+    using the "present" function with ``key_state: 'Disabled'``.
 
     Args:
         name(str):
@@ -418,7 +421,8 @@ async def absent(
               Idem automatically considers this resource being absent if this field is not specified.
 
         pending_window_in_days(int, Optional):
-            The waiting period, specified in number of days. After the waiting period ends, KMS deletes the KMS key. Default value is ``7``.
+            The waiting period, specified in number of days. After the waiting period ends, KMS deletes the KMS key.
+            Default value is ``7``.
 
     Returns:
         Dict[str, Any]
@@ -458,15 +462,15 @@ async def absent(
         result["old_state"] = copy.deepcopy(before["ret"])
 
         if before["ret"].get("deletion_date", None):
-            result["comment"] = (
-                f"aws.kms.key '{resource_id}' already scheduled to be deleted in '{pending_window_in_days}' days",
-            )
+            result[
+                "comment"
+            ] = f"aws.kms.key '{resource_id}' already scheduled to be deleted in '{pending_window_in_days}' days"
             return result
 
         if ctx.get("test", False):
-            result["comment"] = (
-                f"Would schedule deletion of aws.kms.key '{resource_id}' in {pending_window_in_days} days",
-            )
+            result[
+                "comment"
+            ] = f"Would schedule deletion of aws.kms.key '{resource_id}' in {pending_window_in_days} days"
             return result
 
         try:
@@ -481,9 +485,9 @@ async def absent(
                 result["comment"] = ret["comment"]
                 result["result"] = False
                 return result
-            result["comment"] = (
-                f"aws.kms.key '{resource_id}' is scheduled for deletion in {pending_window_in_days} days",
-            )
+            result[
+                "comment"
+            ] = f"aws.kms.key '{resource_id}' is scheduled for deletion in {pending_window_in_days} days"
         except hub.tool.boto3.exception.ClientError as e:
             result["comment"] = (f"{e.__class__.__name__}: {e}",)
 
