@@ -232,10 +232,9 @@ async def present(
     )
     if before["result"] and before["ret"].get("Configuration"):
         function = before["ret"].get("Configuration")
-        code_config = before["ret"].get("Code")
         function_arn = function.get("FunctionArn")
         existing_tags = before.get("ret").get("Tags")
-        resource_converted = await hub.tool.aws.lambda_aws.conversion_utils.convert_raw_lambda_function_to_present(
+        resource_converted = await hub.tool.aws.lambda_aws.conversion_utils.convert_raw_lambda_function_to_present_async(
             ctx,
             raw_resource=function,
             idem_resource_name=name,
@@ -247,48 +246,36 @@ async def present(
         result["old_state"] = resource_converted["ret"]
         plan_state = copy.deepcopy(result["old_state"])
 
-        update = {
-            "FunctionName": name,
-            "ZipFile": code.get("ZipFile"),
-            "S3Bucket": code.get("S3Bucket"),
-            "S3Key": code.get("S3Key"),
-            "S3ObjectVersion": code.get("S3ObjectVersion"),
-            "ImageUri": code.get("ImageUri"),
-            "Publish": publish,
-            "RevisionId": revision_id,
-            "Architectures": architectures,
-            "Role": role,
-            "Handler": handler,
-            "Description": description,
-            "Timeout": function_timeout,
-            "MemorySize": memory_size,
-            "VpcConfig": vpc_config,
-            "Environment": environment,
-            "Runtime": runtime,
-            "DeadLetterConfig": dead_letter_config,
-            "KMSKeyArn": kms_key_arn,
-            "TracingConfig": tracing_config,
-            "Layers": layers,
-            "Code": code,
-            "Tags": tags,
-            "FileSystemConfigs": file_system_configs,
-            "ImageConfig": image_config,
-            "Qualifier": qualifier,
-            "MaximumRetryAttempts": maximum_retry_attempts,
-            "MaximumEventAgeInSeconds": maximum_event_age_in_seconds,
-            "DestinationConfig": destination_config,
-            "CodeSigningConfigArn": code_signing_config_arn,
-            "PackageType": package_type,
-        }
         update_return = await hub.tool.aws.lambda_aws.function.compare_inputs_and_update_lambda_function(
-            ctx=ctx,
+            ctx,
             name=name,
-            function=function,
-            update=update,
-            code=code_config,
-            timeout=timeout,
-            plan_state=plan_state,
+            code=code,
             resource_id=resource_id,
+            plan_state=plan_state,
+            old_state=result["old_state"],
+            zip_file=code.get("ZipFile"),
+            s3_bucket=code.get("S3Bucket"),
+            s3_key=code.get("S3Key"),
+            s3_object_version=code.get("S3ObjectVersion"),
+            image_uri=code.get("ImageUri"),
+            publish=publish,
+            revision_id=revision_id,
+            architectures=architectures,
+            role=role,
+            handler=handler,
+            description=description,
+            function_timeout=function_timeout,
+            memory_size=memory_size,
+            vpc_config=vpc_config,
+            environment=environment,
+            runtime=runtime,
+            dead_letter_config=dead_letter_config,
+            kms_key_arn=kms_key_arn,
+            tracing_config=tracing_config,
+            layers=layers,
+            file_system_configs=file_system_configs,
+            image_config=image_config,
+            timeout=timeout,
         )
         result["result"] = result["result"] and update_return["result"]
         result["comment"] = result["comment"] + update_return["comment"]
@@ -414,7 +401,7 @@ async def present(
         final_updated_tags = (
             after.get("ret").get("Tags") if are_tags_updated else existing_tags
         )
-        resource_converted = await hub.tool.aws.lambda_aws.conversion_utils.convert_raw_lambda_function_to_present(
+        resource_converted = await hub.tool.aws.lambda_aws.conversion_utils.convert_raw_lambda_function_to_present_async(
             ctx=ctx,
             raw_resource=after["ret"].get("Configuration"),
             idem_resource_name=name,
@@ -481,7 +468,7 @@ async def absent(
         result["comment"] = (f"aws.lambda.function '{name}' already absent",)
     else:
         existing_tags = before.get("ret").get("Tags")
-        resource_converted = await hub.tool.aws.lambda_aws.conversion_utils.convert_raw_lambda_function_to_present(
+        resource_converted = await hub.tool.aws.lambda_aws.conversion_utils.convert_raw_lambda_function_to_present_async(
             ctx,
             raw_resource=before["ret"].get("Configuration"),
             idem_resource_name=resource_id,
@@ -510,7 +497,7 @@ async def absent(
                     ctx, FunctionName=resource_id, Qualifier=qualifier
                 )
                 if after["result"] and after["ret"]:
-                    resource_converted = await hub.tool.aws.lambda_aws.conversion_utils.convert_raw_lambda_function_to_present(
+                    resource_converted = await hub.tool.aws.lambda_aws.conversion_utils.convert_raw_lambda_function_to_present_async(
                         ctx,
                         raw_resource=after["ret"].get("Configuration"),
                         idem_resource_name=resource_id,
@@ -556,7 +543,7 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
             tags = await hub.exec.boto3.client["lambda"].list_tags(
                 ctx, Resource=function.get("FunctionArn")
             )
-            resource_converted = await hub.tool.aws.lambda_aws.conversion_utils.convert_raw_lambda_function_to_present(
+            resource_converted = await hub.tool.aws.lambda_aws.conversion_utils.convert_raw_lambda_function_to_present_async(
                 ctx,
                 raw_resource=function,
                 idem_resource_name=function.get("FunctionName"),
