@@ -103,63 +103,46 @@ async def present(
     update_parent = False
 
     if resource_id:
-        before = await hub.exec.boto3.client.organizations.describe_account(
-            ctx, AccountId=resource_id
+        before = await hub.exec.aws.organizations.account.get(
+            ctx, resource_id=resource_id, name=name
         )
+        if not before["result"]:
+            result["result"] = before["result"]
+            result["comment"] = before["comment"]
+            return result
 
     if isinstance(tags, List):
         tags = hub.tool.aws.tag_utils.convert_tag_list_to_dict(tags)
 
-    if before:
+    if before and before["ret"]:
         # Account exists , update
         try:
-            old_tags = await hub.exec.boto3.client.organizations.list_tags_for_resource(
-                ctx, ResourceId=resource_id
-            )
-            result["result"] = result["result"] and old_tags["result"]
-            if not result["result"]:
-                result["comment"] = result["comment"] + old_tags["comment"]
-                return result
-            old_tags = old_tags["ret"].get("Tags") if old_tags else None
+            result["old_state"] = before["ret"]
+            plan_state = copy.deepcopy(result["old_state"])
             # we need to list parents to check if move is required in case the new_parent_id is not equal to current_
             # parent_id
-            parents = await hub.exec.boto3.client.organizations.list_parents(
-                ctx, ChildId=resource_id
-            )
-            result["result"] = result["result"] and parents["result"]
-            if not result["result"]:
-                result["comment"] = result["comment"] + parents["comment"]
-                return result
-            if parents:
-                current_parent_id = parents["ret"]["Parents"][0]["Id"]
-                if parent_id is not None and current_parent_id != parent_id:
-                    if not ctx.get("test", False):
-                        move_account_result = (
-                            await hub.tool.aws.organizations.account.move_account(
-                                ctx, resource_id, result, parent_id
-                            )
+            current_parent_id = before["ret"]["parent_id"]
+            if current_parent_id and parent_id and current_parent_id != parent_id:
+                if not ctx.get("test", False):
+                    move_account_result = (
+                        await hub.tool.aws.organizations.account.move_account(
+                            ctx, resource_id, result, parent_id
                         )
-                        if move_account_result and not move_account_result["result"]:
-                            result["comment"] = result["comment"] + (
-                                f"Could not update parent for aws.organizations.account {name}",
-                            )
-                            result["result"] = False
-                            return result
-                    update_parent = True
-            result[
-                "old_state"
-            ] = hub.tool.aws.organizations.conversion_utils.convert_raw_account_to_present(
-                current_parent_id if parents else None,
-                before["ret"]["Account"],
-                old_tags if old_tags else None,
-            )
-            plan_state = copy.deepcopy(result["old_state"])
+                    )
+                    if move_account_result and not move_account_result["result"]:
+                        result["comment"] = result["comment"] + (
+                            f"Could not update parent for aws.organizations.account {name}",
+                        )
+                        result["result"] = False
+                        return result
+                update_parent = True
             if update_parent:
                 plan_state["parent_id"] = parent_id
                 result["comment"] = result["comment"] + (
                     f"Would update parent for aws.organizations.account {name}",
                 )
 
+            # update tags
             if tags is not None and tags != result["old_state"].get("tags"):
                 update_tags_ret = await hub.tool.aws.organizations.tag.update_tags(
                     ctx, resource_id, result["old_state"].get("tags"), tags
@@ -197,7 +180,9 @@ async def present(
                     "tags": tags,
                 },
             )
-            result["comment"] = (f"Would create aws.organizations.account {name}",)
+            result["comment"] = hub.tool.aws.comment_utils.would_create_comment(
+                resource_type="aws.organizations.account", name=name
+            )
             return result
 
         try:
@@ -276,7 +261,9 @@ async def present(
                     return result
                 elif account_state == "SUCCEEDED":
                     resource_id = create_account_status["AccountId"]
-                    result["comment"] = (f"Created aws.organizations.account {name}.",)
+                    result["comment"] = hub.tool.aws.comment_utils.create_comment(
+                        resource_type="aws.organizations.account", name=name
+                    )
                     if resource_id is not None and parent_id is not None:
                         parents = (
                             await hub.exec.boto3.client.organizations.list_parents(
@@ -289,7 +276,6 @@ async def present(
                             return result
                         if parents:
                             current_parent_id = parents["ret"]["Parents"][0]["Id"]
-
                             if current_parent_id != parent_id:
                                 move_account_result = await hub.tool.aws.organizations.account.move_account(
                                     ctx, resource_id, result, parent_id
@@ -316,37 +302,11 @@ async def present(
         result["new_state"] = plan_state
     elif not before or update_parent or update_tag and resource_id:
         try:
-            after = await hub.exec.boto3.client.organizations.describe_account(
-                ctx, AccountId=resource_id
+            after = await hub.exec.aws.organizations.account.get(
+                ctx, resource_id=resource_id, name=name
             )
             if after and after.get("ret"):
-
-                parents = await hub.exec.boto3.client.organizations.list_parents(
-                    ctx, ChildId=resource_id
-                )
-                result["result"] = result["result"] and parents["result"]
-                if not result["result"]:
-                    result["comment"] = result["comment"] + parents["comment"]
-                    return result
-                if parents:
-                    current_parent_id = parents["ret"]["Parents"][0]["Id"]
-
-                new_tags = (
-                    await hub.exec.boto3.client.organizations.list_tags_for_resource(
-                        ctx, ResourceId=resource_id
-                    )
-                )
-                result["result"] = result["result"] and new_tags["result"]
-                if not result["result"]:
-                    result["comment"] = result["comment"] + new_tags["comment"]
-                    return result
-                result[
-                    "new_state"
-                ] = hub.tool.aws.organizations.conversion_utils.convert_raw_account_to_present(
-                    current_parent_id if parents else None,
-                    after["ret"]["Account"],
-                    new_tags["ret"].get("Tags") if new_tags else None,
-                )
+                result["new_state"] = after["ret"]
             else:
                 result["result"] = result["result"] and after["result"]
                 if not result["result"]:
@@ -399,40 +359,43 @@ async def absent(hub, ctx, name: str, resource_id: str) -> Dict[str, Any]:
     """
     result = dict(comment=(), old_state=None, new_state=None, name=name, result=True)
 
-    before = await hub.exec.boto3.client.organizations.describe_account(
-        ctx, AccountId=resource_id
+    before = await hub.exec.aws.organizations.account.get(
+        ctx, resource_id=resource_id, name=name
     )
 
-    if not before:
-        result["comment"] = (f"aws.organizations.account {name} already absent",)
-    elif ctx.get("test", False):
-        result["comment"] = (f"Would delete aws.organizations.account {name}.",)
-    else:
+    if not before["result"]:
+        result["result"] = before["result"]
+        result["comment"] = before["comment"]
+        return result
 
+    if not before["ret"]:
+        result["comment"] = hub.tool.aws.comment_utils.already_absent_comment(
+            resource_type="aws.organizations.account",
+            name=name,
+        )
+    elif ctx.get("test", False):
+        result["comment"] = hub.tool.aws.comment_utils.would_delete_comment(
+            resource_type="aws.organizations.account",
+            name=name,
+        )
+    else:
         try:
             ret = await hub.exec.boto3.client.organizations.remove_account_from_organization(
                 ctx, AccountId=resource_id
             )
-
             result["result"] = ret["result"]
-
             if not result["result"]:
                 result["comment"] = result["comment"] + ret["comment"]
                 return result
-            result["comment"] = result["comment"] + (
-                f"aws.organizations.account {name} deleted.",
+            result["comment"] = hub.tool.aws.comment_utils.delete_comment(
+                resource_type="aws.organizations.account", name=name
             )
         except hub.tool.boto3.exception.ClientError as e:
             result["comment"] = result["comment"] + (f"{e.__class__.__name__}: {e}",)
             result["result"] = False
 
     if before:
-        result[
-            "old_state"
-        ] = hub.tool.aws.organizations.conversion_utils.convert_raw_account_to_present(
-            None, before["ret"]["Account"], None
-        )
-
+        result["old_state"] = before["ret"]
     return result
 
 
@@ -449,45 +412,19 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
     """
     result = {}
 
-    describe_ret = await hub.exec.boto3.client.organizations.list_accounts(ctx)
-    if not describe_ret:
-        hub.log.debug(f"Could not describe account {describe_ret['comment']}")
+    describe_ret = await hub.exec.aws.organizations.account.list(ctx)
+    if not describe_ret["ret"]:
+        hub.log.debug(f"Could not list accounts {describe_ret['comment']}")
         return {}
 
-    accounts = describe_ret["ret"]["Accounts"]
+    accounts = describe_ret["ret"]
 
     for account in accounts:
-        parent = await hub.exec.boto3.client.organizations.list_parents(
-            ctx, ChildId=account["Id"]
-        )
-        if parent and not parent["result"]:
-            hub.log.debug(
-                f"Unable to list parent for account: {account['Id']} Error:  {describe_ret['comment']}"
-            )
-            continue
-
-        tags = await hub.exec.boto3.client.organizations.list_tags_for_resource(
-            ctx, ResourceId=account["Id"]
-        )
-        if tags and not tags["result"]:
-            hub.log.debug(
-                f"Unable to list tags for account: {account['Id']} Error:  {tags['comment']}"
-            )
-            continue
-        translated_resource = (
-            hub.tool.aws.organizations.conversion_utils.convert_raw_account_to_present(
-                parent["ret"]["Parents"][0]["Id"]
-                if parent and parent["ret"].get("Parents")
-                else None,
-                account,
-                tags["ret"].get("Tags") if tags and tags["ret"].get("Tags") else None,
-            )
-        )
-
-        result[account["Id"]] = {
+        account_id = account["resource_id"]
+        result[account_id] = {
             "aws.organizations.account.present": [
                 {parameter_key: parameter_value}
-                for parameter_key, parameter_value in translated_resource.items()
+                for parameter_key, parameter_value in account.items()
             ]
         }
     return result
