@@ -79,6 +79,9 @@ TREQ = {
     "present": {
         "require": ["aws.rds.db_subnet_group.present"],
     },
+    "absent": {
+        "require": ["aws.rds.db_instance"],
+    },
 }
 
 
@@ -793,28 +796,31 @@ async def present(
                     - Key: name
                       Value: value
     '''
-    result = dict(comment=(), old_state="", new_state="", name=name, result=True)
+    result = {
+        "comment": (),
+        "old_state": None,
+        "new_state": None,
+        "name": name,
+        "result": True,
+    }
     params_to_modify = {}
     before = None
     plan_state = None
     resource_updated = False
     if resource_id:
-        before = await hub.exec.boto3.client.rds.describe_db_clusters(
-            ctx, DBClusterIdentifier=resource_id
+        before = await hub.exec.aws.rds.db_cluster.get(
+            ctx,
+            resource_id=resource_id,
         )
     tags = (
         hub.tool.aws.tag_utils.convert_tag_list_to_dict(tags)
         if isinstance(tags, List)
         else tags
     )
-    if before and before.get("ret"):
-        result[
-            "old_state"
-        ] = hub.tool.aws.rds.conversion_utils.convert_raw_db_cluster_to_present(
-            raw_resource=before["ret"]["DBClusters"][0], idem_resource_name=name
-        )
+    if before:
+        result["old_state"] = before["ret"]
         plan_state = copy.deepcopy(result["old_state"])
-        resource_arn = before["ret"]["DBClusters"][0].get("DBClusterArn")
+        resource_arn = before["ret"].get("db_cluster_arn")
         old_tags = result["old_state"].get("tags")
         if tags is not None and old_tags != tags:
             update_tags_ret = await hub.exec.aws.rds.tag.update_rds_tags(
@@ -1124,15 +1130,11 @@ async def present(
     if ctx.get("test", False):
         result["new_state"] = plan_state
     elif (not before) or resource_updated:
-        after = await hub.exec.boto3.client.rds.describe_db_clusters(
+        after = await hub.exec.aws.rds.db_cluster.get(
             ctx,
-            DBClusterIdentifier=resource_id,
-        )
-        result[
-            "new_state"
-        ] = hub.tool.aws.rds.conversion_utils.convert_raw_db_cluster_to_present(
-            raw_resource=after["ret"]["DBClusters"][0], idem_resource_name=name
+            resource_id=resource_id,
         )
+        result["new_state"] = after["ret"]
     else:
         result["new_state"] = copy.deepcopy(result["old_state"])
     return result
@@ -1189,7 +1191,13 @@ async def absent(
                 - resource_id: test-db-cluster
                 - skip_final_snapshot: true
     """
-    result = dict(comment=(), old_state="", new_state="", name=name, result=True)
+    result = {
+        "comment": (),
+        "old_state": "",
+        "new_state": "",
+        "name": name,
+        "result": True,
+    }
 
     if not resource_id:
         result["comment"] = hub.tool.aws.comment_utils.already_absent_comment(
@@ -1197,8 +1205,9 @@ async def absent(
         )
         return result
 
-    before = await hub.exec.boto3.client.rds.describe_db_clusters(
-        ctx, DBClusterIdentifier=resource_id
+    before = await hub.exec.aws.rds.db_cluster.get(
+        ctx,
+        resource_id=resource_id,
     )
 
     if not before["ret"]:
@@ -1207,11 +1216,7 @@ async def absent(
         )
 
     else:
-        result[
-            "old_state"
-        ] = hub.tool.aws.rds.conversion_utils.convert_raw_db_cluster_to_present(
-            raw_resource=before["ret"]["DBClusters"][0], idem_resource_name=name
-        )
+        result["old_state"] = before["ret"]
         if ctx.get("test", False):
             result["comment"] = hub.tool.aws.comment_utils.would_delete_comment(
                 resource_type="aws.rds.db_cluster", name=name
