@@ -421,15 +421,22 @@ async def present(
                       max_attempts: 30
 
     '''
-    result = dict(comment=(), old_state=None, new_state=None, name=name, result=True)
+    result = {
+        "comment": (),
+        "old_state": None,
+        "new_state": None,
+        "name": name,
+        "result": True,
+    }
     params_to_modify = {}
     plan_state = None
     before = None
     resource_updated = False
 
     if resource_id:
-        before = await hub.exec.boto3.client.rds.describe_db_instances(
-            ctx, DBInstanceIdentifier=resource_id
+        before = await hub.exec.aws.rds.db_instance.get(
+            ctx,
+            resource_id=resource_id,
         )
     tags = (
         hub.tool.aws.tag_utils.convert_tag_list_to_dict(tags)
@@ -437,7 +444,8 @@ async def present(
         else tags
     )
     if before and before.get("ret"):
-        db_instance_arn = before["ret"]["DBInstances"][0].get("DBInstanceArn")
+        db_instance_arn = before["ret"].get("db_instance_arn")
+        before["ret"]["name"] = before["ret"]["tags"].get("Name")
         ret_tags = await hub.exec.boto3.client.rds.list_tags_for_resource(
             ctx, ResourceName=db_instance_arn
         )
@@ -445,13 +453,7 @@ async def present(
             result["comment"] = ret_tags["comment"]
             result["result"] = False
             return result
-        result[
-            "old_state"
-        ] = hub.tool.aws.rds.conversion_utils.convert_raw_db_instance_to_present(
-            raw_resource=before["ret"]["DBInstances"][0],
-            raw_resource_tags=ret_tags,
-            idem_resource_name=name,
-        )
+        result["old_state"] = before["ret"]
         plan_state = copy.deepcopy(result["old_state"])
         old_tags = plan_state.get("tags")
 
@@ -715,23 +717,19 @@ async def present(
     if ctx.get("test", False):
         result["new_state"] = plan_state
     elif (not before) or resource_updated:
-        after = await hub.exec.boto3.client.rds.describe_db_instances(
-            ctx, DBInstanceIdentifier=resource_id
+        after = await hub.exec.aws.rds.db_instance.get(
+            ctx,
+            resource_id=resource_id,
         )
-        db_instance_arn = after["ret"]["DBInstances"][0].get("DBInstanceArn")
+        after["ret"]["name"] = name
+        db_instance_arn = after["ret"].get("db_instance_arn")
         ret_tags = await hub.exec.boto3.client.rds.list_tags_for_resource(
             ctx, ResourceName=db_instance_arn
         )
         if not ret_tags["result"]:
             result["comment"] = result["comment"] + ret_tags["comment"]
             result["result"] = False
-        result[
-            "new_state"
-        ] = hub.tool.aws.rds.conversion_utils.convert_raw_db_instance_to_present(
-            raw_resource=after["ret"]["DBInstances"][0],
-            raw_resource_tags=ret_tags,
-            idem_resource_name=name,
-        )
+        result["new_state"] = after["ret"]
     else:
         result["new_state"] = copy.deepcopy(result["old_state"])
 
@@ -742,7 +740,7 @@ async def absent(
     hub,
     ctx,
     name: str,
-    resource_id: str,
+    resource_id: str = None,
     skip_final_snapshot: bool = None,
     final_db_snapshot_identifier: str = None,
     timeout: Dict = None,
@@ -765,7 +763,7 @@ async def absent(
         name(str):
             Idem name to identify the resource.
 
-        resource_id(str):
+        resource_id(str, Optional):
             AWS ID to identify the resource.
 
         skip_final_snapshot(bool, Optional):
@@ -792,17 +790,23 @@ async def absent(
                 - resource_id: test-db-instance,
                 - skip_final_snapshot: true
     """
-    result = dict(comment=(), old_state=None, new_state=None, name=name, result=True)
+    result = {
+        "comment": (),
+        "old_state": None,
+        "new_state": None,
+        "name": name,
+        "result": True,
+    }
 
-    before = await hub.exec.boto3.client.rds.describe_db_instances(
-        ctx, DBInstanceIdentifier=resource_id
+    before = await hub.exec.aws.rds.db_instance.get(
+        ctx,
+        resource_id=resource_id,
     )
 
     if not before["ret"]:
         result["comment"] = (f"aws.rds.db_instance '{name}' already absent",)
-
     else:
-        db_instance_arn = before["ret"]["DBInstances"][0].get("DBInstanceArn")
+        db_instance_arn = before["ret"].get("db_instance_arn")
         ret_tags = await hub.exec.boto3.client.rds.list_tags_for_resource(
             ctx, ResourceName=db_instance_arn
         )
@@ -810,13 +814,7 @@ async def absent(
             result["comment"] = ret_tags["comment"]
             result["result"] = False
             return result
-        result[
-            "old_state"
-        ] = hub.tool.aws.rds.conversion_utils.convert_raw_db_instance_to_present(
-            raw_resource=before["ret"]["DBInstances"][0],
-            raw_resource_tags=ret_tags,
-            idem_resource_name=name,
-        )
+        result["old_state"] = before["ret"]
         if ctx.get("test", False):
             result["comment"] = (f"Would delete aws.rds.db_instance '{name}'",)
             return result
@@ -875,24 +873,19 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
     """
 
     result = {}
-    ret = await hub.exec.boto3.client.rds.describe_db_instances(ctx)
+    ret = await hub.exec.aws.rds.db_instance.list(ctx)
     if not ret["result"]:
         hub.log.debug(f"Could not describe db_instance {ret['comment']}")
         return result
-    for db_instance in ret["ret"]["DBInstances"]:
+    for db_instance in ret["ret"]:
         # Including fields to match the 'present' function parameters
-        resource_id = db_instance.get("DBInstanceIdentifier")
-        db_instance_arn = db_instance.get("DBInstanceArn")
+        resource_id = db_instance.get("resource_id")
+        db_instance["name"] = db_instance["tags"].get("Name")
+        db_instance_arn = db_instance.get("db_instance_arn")
         ret_tags = await hub.exec.boto3.client.rds.list_tags_for_resource(
             ctx, ResourceName=db_instance_arn
         )
-        resource_translated = (
-            hub.tool.aws.rds.conversion_utils.convert_raw_db_instance_to_present(
-                raw_resource=db_instance,
-                raw_resource_tags=ret_tags,
-                idem_resource_name=resource_id,
-            )
-        )
+        resource_translated = db_instance
         result[resource_id] = {
             "aws.rds.db_instance.present": [
                 {parameter_key: parameter_value}
