@@ -88,11 +88,18 @@ async def present(
     """
 
     plan_state = {}
-    result = dict(comment=(), old_state=None, new_state=None, name=name, result=True)
+    result = {
+        "comment": (),
+        "old_state": None,
+        "new_state": None,
+        "name": name,
+        "result": True,
+    }
     before = None
     if resource_id:
-        before = await hub.exec.boto3.client.rds.describe_db_subnet_groups(
-            ctx, DBSubnetGroupName=resource_id
+        before = await hub.exec.aws.rds.db_subnet_group.get(
+            ctx,
+            resource_id=resource_id,
         )
     tags = (
         hub.tool.aws.tag_utils.convert_tag_list_to_dict(tags)
@@ -106,13 +113,8 @@ async def present(
     old_tag = None
     if before and before["result"]:
         try:
-            subnet_list = []
-            old_db_subnet_group = hub.tool.aws.rds.conversion_utils.convert_raw_db_subnet_group_to_present(
-                resource=before["ret"]["DBSubnetGroups"][0],
-                idem_resource_name=name,
-            )
-            for each_subnet in old_db_subnet_group.get("subnets"):
-                subnet_list.append(each_subnet)
+            old_db_subnet_group = before["ret"]
+            subnet_list = old_db_subnet_group["subnets"]
             if set(subnets) != set(subnet_list):
                 is_updated = True
             db_subnet_group_arn = old_db_subnet_group.get("db_subnet_group_arn")
@@ -217,13 +219,11 @@ async def present(
         if ctx.get("test", False):
             new_db_subnet_group = plan_state
         elif is_updated or not (before and before["result"]):
-            after = await hub.exec.boto3.client.rds.describe_db_subnet_groups(
-                ctx, DBSubnetGroupName=name
-            )
-            new_db_subnet_group = hub.tool.aws.rds.conversion_utils.convert_raw_db_subnet_group_to_present(
-                resource=after["ret"]["DBSubnetGroups"][0],
-                idem_resource_name=name,
+            after = await hub.exec.aws.rds.db_subnet_group.get(
+                ctx,
+                resource_id=name,
             )
+            new_db_subnet_group = after["ret"]
         else:
             new_db_subnet_group = copy.deepcopy(old_db_subnet_group)
 
@@ -276,7 +276,13 @@ async def absent(
                 - name: value
     """
 
-    result = dict(comment=(), old_state=None, new_state=None, name=name, result=True)
+    result = {
+        "comment": (),
+        "old_state": None,
+        "new_state": None,
+        "name": name,
+        "result": True,
+    }
     if not resource_id:
         result["comment"] = hub.tool.aws.comment_utils.already_absent_comment(
             resource_type="aws.rds.db_subnet_group", name=name
@@ -309,7 +315,6 @@ async def absent(
                 )
                 if tags.get("result")
                 else None,
-                idem_resource_name=name,
             )
             if ctx.get("test", False):
                 result["comment"] = hub.tool.aws.comment_utils.would_delete_comment(
@@ -379,7 +384,6 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
             resource_converted = hub.tool.aws.rds.conversion_utils.convert_raw_db_subnet_group_to_present(
                 resource=db_subnet_group,
                 tags=tags,
-                idem_resource_name=db_subnet_group_id,
             )
             result[db_subnet_group_id] = {
                 "aws.rds.db_subnet_group.present": [
