@@ -1,3 +1,4 @@
+"""State module for managing Route53 Hosted zone associations."""
 import copy
 import re
 from dataclasses import field
@@ -34,46 +35,54 @@ async def present(
         ],
     ) = None,
 ) -> Dict[str, Any]:
-    """
-    Associates the specified vpc to the specified hosted zone.
+    """Associates the specified vpc to the specified hosted zone.
 
     Args:
-        hub:
-        ctx:
-        name(Text): An Idem name of the AWS hosted zone vpc association.
-        zone_id(Text): The id of hosted zone to associate to a vpc
-        vpc_id(Text): The id of the vpc to associate to a hosted zone.
-        vpc_region(Text, optional): The AWS region where the vpc belongs to.
-                                    If the vpc_region is not specified, AWS region from credentials file will be used.
-        resource_id(Text, optional): The identifier for this object, combination of hosted_zone id, vpc id and vpc region separated by a separator ':'
-        comment(Text, optional): A comment about the association request.
-        timeout(Dict, optional): Timeout configuration for create/update of AWS DB Cluster.
-            * create (Dict) -- Timeout configuration for creating DB Cluster
-                * delay -- The amount of time in seconds to wait between attempts.
-                * max_attempts -- Customized timeout configuration containing delay and max attempts.
-        timeout(Dict, optional): Timeout configuration for hosted zone and vpc association.
-            * create (Dict) -- Timeout configuration for creating nat gateway
-                 * delay (int) -- The amount of time in seconds to wait between attempts. Defaults to 15.
-                * max_attempts(int) -- Customized timeout configuration containing delay and max attempts. Defaults to 40.
+        name(str):
+            An Idem name of the AWS hosted zone vpc association.
+
+        zone_id(str):
+            The id of hosted zone to associate to a vpc
+
+        vpc_id(str):
+            The id of the vpc to associate to a hosted zone.
+
+        vpc_region(str, Optional):
+            The AWS region where the vpc belongs to. If the vpc_region is not specified, AWS region from credentials file
+            will be used.
+
+        resource_id(str, Optional):
+            The identifier for this object, combination of hosted_zone id, vpc id and vpc region separated by a separator ':'
+
+        comment(str, Optional):
+            A comment about the association request.
+
+        timeout(dict, Optional):
+            Timeout configuration for hosted zone and vpc association.
+
+            * create (dict): Timeout configuration for creating nat gateway
+                * delay (int): The amount of time in seconds to wait between attempts. Defaults to 15.
+                * max_attempts(int): Customized timeout configuration containing delay and max attempts. Defaults to 40.
 
     Request Syntax:
-        [zone_id:vpc_id:vpc_region]:
-          aws.route53.hosted_zone_association.present:
-          - resource_id: 'string'
-          - zone_id: 'string'
-          - vpc_id: 'string'
-          - vpc_region: 'string'
-          - comment: 'string'
-          - timeout:
-              create
-                delay: 'integer'
-                max_attempts: 'integer'
+        .. code-block:: sls
+
+            [zone_id:vpc_id:vpc_region]:
+              aws.route53.hosted_zone_association.present:
+                - resource_id: 'string'
+                - zone_id: 'string'
+                - vpc_id: 'string'
+                - vpc_region: 'string'
+                - comment: 'string'
+                - timeout:
+                    create:
+                      delay: 'integer'
+                      max_attempts: 'integer'
 
     Returns:
         Dict[str, Any]
 
     Examples:
-
         .. code-block:: sls
 
             Z09756241DYDBTZK8J11E:vpc-9aacf0f2:eu-central-1:
@@ -106,7 +115,7 @@ async def present(
     if vpc_region is None:
         vpc_region = ctx["acct"].get("region_name")
     if not (vpc_id == "resource_id_known_after_present"):
-        before = await hub.exec.aws.route53.hosted_zone_association.is_hosted_zone_associated_to_vpc(
+        before = await hub.tool.aws.route53.hosted_zone_association.is_hosted_zone_associated_to_vpc(
             ctx, zone_id=zone_id, vpc_id=vpc_id, vpc_region=vpc_region
         )
         if not before["result"]:
@@ -198,25 +207,43 @@ async def absent(
     comment: str = None,
     timeout: Dict = None,
 ) -> Dict[str, Any]:
-    """
-
-    Removes the specified managed policy from the specified role.
+    """Removes the specified managed policy from the specified role.
 
     Args:
-        name(Text): An Idem name of the AWS hosted zone vpc association.
-        resource_id(Text, optional): The id of the hosted zone and vpc association. Idem automatically considers this resource being absent
-         if this field is not specified.
-        comment(Text, optional): A comment about the disassociation request.
-        timeout(Dict, optional): Timeout configuration for hosted zone and vpc association.
-            * delete (Dict) -- Timeout configuration for creating nat gateway
-                    * delay (int) -- The amount of time in seconds to wait between attempts. Defaults to 15.
-                    * max_attempts(int) -- Customized timeout configuration containing delay and max attempts. Defaults to 40.
+        name(str):
+            An Idem name of the AWS hosted zone vpc association.
+
+        resource_id(str, Optional):
+            The id of the hosted zone and vpc association. Idem automatically considers this resource being absent if
+            this field is not specified.
+
+        comment(str, Optional):
+            A comment about the disassociation request.
+
+        timeout(dict, Optional):
+            Timeout configuration for hosted zone and vpc association.
+
+            * delete (dict): Timeout configuration for creating nat gateway
+                    * delay (int): The amount of time in seconds to wait between attempts. Defaults to 15.
+                    * max_attempts(int): Customized timeout configuration containing delay and max attempts. Defaults to 40.
+
+    Request Syntax:
+        .. code-block:: sls
+
+            [hosted_zone_association-resource-id]:
+              aws.route53.hosted_zone_association.absent:
+                - name: "string"
+                - resource_id: "string"
+                - comment: "string"
+                - timeout:
+                    delete:
+                        delay: "integer"
+                        max_attempts: "integer"
 
     Returns:
         Dict[str, Any]
 
     Examples:
-
         .. code-block:: sls
 
             Z09756241DYDBTZK8J11E:vpc-9aacf0f2:eu-central-1:
@@ -248,7 +275,7 @@ async def absent(
     if not vpc_region:
         vpc_region = ctx["acct"].get("region_name")
 
-    before_ret = await hub.exec.aws.route53.hosted_zone_association.is_hosted_zone_associated_to_vpc(
+    before_ret = await hub.tool.aws.route53.hosted_zone_association.is_hosted_zone_associated_to_vpc(
         ctx, zone_id=zone_id, vpc_id=vpc_id, vpc_region=vpc_region
     )
 
@@ -318,10 +345,8 @@ async def absent(
 
 async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
     """
-
     Describe the resource in a way that can be recreated/managed with the corresponding "present" function
 
-
     Lists the associated vpc's with respective hosted zones. If there are no vpc associated with the specified hosted
     zone, the operation returns an empty dict.
 
@@ -329,7 +354,6 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
         Dict[str, Any]
 
     Examples:
-
         .. code-block:: bash
 
             $ idem describe aws.route53.hosted_zone_association
