@@ -1,4 +1,5 @@
 """State module for managing Route53 Resource records."""
+import copy
 from typing import Any
 from typing import Dict
 from typing import List
@@ -180,6 +181,8 @@ async def present(
             result["comment"] = hub.tool.aws.comment_utils.update_comment(
                 resource_type="aws.route53.resource_record", name=formatted_name
             )
+    else:
+        result["new_state"] = copy.deepcopy(result["old_state"])
 
     return result
 
