@@ -260,6 +260,11 @@ async def present(
                     "object_lock_enabled_for_bucket"
                 ] = object_lock_enabled_for_bucket
                 plan_state["object_lock_configuration"] = object_lock_configuration
+                result["comment"] = result[
+                    "comment"
+                ] + hub.tool.aws.comment_utils.would_update_comment(
+                    resource_type="aws.s3.bucket", name=name
+                )
         if (
             tags_dict is not None
             and not hub.tool.aws.state_comparison_utils.compare_dicts(
