@@ -273,15 +273,15 @@ async def absent(
         ctx, Bucket=resource_id
     )
     if not before_ret["result"]:
-        if "ServerSideEncryptionConfigurationNotFoundError" not in str(
+        if "ServerSideEncryptionConfigurationNotFoundError" in str(
             before_ret["comment"][0]
-        ):
-            result["result"] = False
-            result["comment"] = before_ret["comment"]
-        else:
+        ) or "NoSuchBucket" in str(before_ret["comment"][0]):
             result["comment"] = hub.tool.aws.comment_utils.already_absent_comment(
                 resource_type=STATE_NAME, name=name
             )
+        else:
+            result["result"] = False
+            result["comment"] = before_ret["comment"]
         return result
 
     result[
