@@ -522,13 +522,15 @@ async def absent(
         ctx, name=name, resource_id=resource_id
     )
     if not before_ret["result"]:
-        if "NoSuchLifecycleConfiguration" not in str(before_ret["comment"][0]):
-            result["result"] = False
-            result["comment"] = before_ret["comment"]
-        else:
+        if "NoSuchLifecycleConfiguration" in str(
+            before_ret["comment"][0]
+        ) or "NoSuchBucket" in str(before_ret["comment"]):
             result["comment"] = hub.tool.aws.comment_utils.already_absent_comment(
                 resource_type=STATE_NAME, name=name
             )
+        else:
+            result["result"] = False
+            result["comment"] = before_ret["comment"]
         return result
     elif not before_ret["ret"]:
         result["comment"] = hub.tool.aws.comment_utils.already_absent_comment(
