@@ -294,6 +294,11 @@ async def absent(hub, ctx, name: str, resource_id: str = None) -> Dict[str, Any]
         ctx, name=name, resource_id=resource_id
     )
     if not before["result"]:
+        if "NoSuchBucket" in str(before["comment"]):
+            result["comment"] = hub.tool.aws.comment_utils.already_absent_comment(
+                resource_type="aws.s3.bucket_logging", name=name
+            )
+            return result
         result["comment"] = before["comment"]
         result["result"] = False
         return result
