@@ -500,7 +500,7 @@ async def absent(
     hub,
     ctx,
     name: str,
-    resource_id: str,
+    resource_id: str = None,
 ) -> Dict[str, Any]:
     """Deletes the replication configuration for an S3 bucket.
 
@@ -510,7 +510,7 @@ async def absent(
 
     Args:
         name(str): Idem name of the bucket.
-        resource_id(str): Name of the bucket on which replication needs to be deleted.
+        resource_id(str, Optional): Name of the bucket on which replication needs to be deleted.
 
     Request Syntax:
         .. code-block:: yaml
@@ -543,6 +543,11 @@ async def absent(
         ctx, name=name, resource_id=resource_id
     )
     if not before["result"]:
+        if "NoSuchBucket" in str(before["comment"]):
+            result["comment"] = hub.tool.aws.comment_utils.already_absent_comment(
+                resource_type="aws.s3.bucket_replication", name=name
+            )
+            return result
         result["comment"] = before["comment"]
         result["result"] = False
         return result
