@@ -196,6 +196,11 @@ async def absent(hub, ctx, name: str, resource_id: str = None) -> Dict[str, Any]
         ctx, Bucket=resource_id
     )
     if not before_ret["result"]:
+        if "NoSuchBucket" in str(before_ret["comment"]):
+            result["comment"] = hub.tool.aws.comment_utils.already_absent_comment(
+                resource_type=STATE_NAME, name=name
+            )
+            return result
         result["result"] = False
         result["comment"] = before_ret["comment"]
         return result
