@@ -414,6 +414,11 @@ async def absent(
         ctx, name=name, resource_id=resource_id
     )
     if not before["result"]:
+        if "NoSuchBucket" in str(before["comment"]):
+            result["comment"] = hub.tool.aws.comment_utils.already_absent_comment(
+                resource_type=STATE_NAME, name=name
+            )
+            return result
         result["result"] = False
         result["comment"] += before["comment"]
         return result
