@@ -146,8 +146,10 @@ async def present(
                         "updated_attributes"
                     )
 
-            else:
-                result["comment"] = (f"aws.sns.topic '{name}' already exists",)
+            if not resource_updated:
+                result["comment"] = result["comment"] + (
+                    f"aws.sns.topic '{name}' already exists",
+                )
 
         except hub.tool.boto3.exception.ClientError as e:
             result["comment"] = result["comment"] + (f"{e.__class__.__name__}: {e}",)
