@@ -1,10 +1,4 @@
-"""
-
-hub.exec.boto3.client.wafv2.associate_web_acl
-hub.exec.boto3.client.wafv2.disassociate_web_acl
-hub.exec.boto3.client.wafv2.get_web_acl_for_resource
-hub.exec.boto3.client.wafv2.list_web_acls
-"""
+"""State module for managing Amazon WAF v2 web ACL associations."""
 import asyncio
 import copy
 from typing import Any
@@ -21,39 +15,51 @@ async def present(
     resource_arn: str,
     resource_id: str = None,
 ) -> Dict[str, Any]:
-    r"""
+    """Associates a web ACL with a regional application resource, to protect the resource.
 
-    Associates a web ACL with a regional application resource, to protect the resource.
-    A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, or an AppSync GraphQL API.
+    A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, an AppSync GraphQL API,
+    or an Amazon Cognito user pool.
 
     Args:
-        name(Text): The idem name for the resource
-        resource_id(Text, Optional): The identifier for this object. resource_arn in this case
-        web_acl_arn: The Amazon Resource Name (ARN) of the web ACL that you want to associate with the resource.
-        resource_arn: The Amazon Resource Name (ARN) of the resource to associate with the web ACL.
+        name(str):
+            An Idem name of the resource.
+        resource_id(str, Optional):
+            The Amazon Resource Name (ARN) of the resource associated with the web ACL.
+        web_acl_arn(str):
+            The Amazon Resource Name (ARN) of the web ACL that you want to associate with the resource.
+        resource_arn(str):
+            The Amazon Resource Name (ARN) of the resource to associate with the web ACL.
+            The ARN must be in one of the following formats:
 
-    Request Syntax:
-        [resource-arn]:
+            * For an Application Load Balancer: ``arn:aws:elasticloadbalancing:region:account-id:loadbalancer/app/load-balancer-name/load-balancer-id``
+            * For an Amazon API Gateway REST API: ``arn:aws:apigateway:region::/restapis/api-id/stages/stage-name``
+            * For an AppSync GraphQL API: ``arn:aws:appsync:region:account-id:apis/GraphQLApiId``
+            * For an Amazon Cognito user pool: ``arn:aws:cognito-idp:region:account-id:userpool/user-pool-id``
+
+    Returns:
+        Dict[str, Any]
+
+    Request syntax:
+      .. code-block:: sls
+
+        [idem_test_aws_wafv2_associate_web_acl]:
           aws.wafv2.associate_web_acl.present:
-          - name: 'string'
-          - resource_id: 'string'
-          - web_acl_arn: 'string'
-          - resource_arn: 'string'
+            - name: 'string'
+            - resource_id: 'string'
+            - web_acl_arn: 'string'
+            - resource_arn: 'string'
 
     Returns:
         Dict[str, Any]
 
     Examples:
-
         .. code-block:: sls
 
-            arn:aws:elasticloadbalancing:us-west-2:123456789012:loadbalancer/app/waf-cli-alb/1ea17125f8b25a2a:
+            idem_test_aws_wafv2_associate_web_acl:
               aws.wafv2.associate_web_acl.present:
-              - name: arn:aws:elasticloadbalancing:us-west-2:123456789012:loadbalancer/app/waf-cli-alb/1ea17125f8b25a2a
-              - web_acl_arn: arn:aws:wafv2:us-west-2:123456789012:regional/webacl/test-cli/a1b2c3d4-5678-90ab-cdef-EXAMPLE11111
-              - resource_arn: arn:aws:elasticloadbalancing:us-west-2:123456789012:loadbalancer/app/waf-cli-alb/1ea17125f8b25a2a
-              - resource_id: arn:aws:elasticloadbalancing:us-west-2:123456789012:loadbalancer/app/waf-cli-alb/1ea17125f8b25a2a
-
+                - name: 'idem_test_associate_web_acl'
+                - web_acl_arn: 'arn:aws:wafv2:us-west-2:123456789012:regional/webacl/idem_test_web_acl/e3706582-69b0-4487-97b6-63f82b8a3147'
+                - resource_arn: 'arn:aws:apigateway:us-west-2::/restapis/1234567890/stages/dev'
     """
     result = dict(comment=(), old_state=None, new_state=None, name=name, result=True)
     before = await hub.exec.boto3.client.wafv2.get_web_acl_for_resource(
@@ -117,30 +123,41 @@ async def absent(
     name: str,
     resource_id: str = None,
 ) -> Dict[str, Any]:
-    r"""
-    **Autogenerated function**
+    """Disassociates the specified regional resource from any existing web ACL association.
 
-    Disassociates a web ACL from a regional application resource.
-    A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, or an AppSync GraphQL API.
+    A resource can have at most one web ACL association. A regional application can be an Application Load Balancer (ALB),
+    an Amazon API Gateway REST API, an AppSync GraphQL API, or an Amazon Cognito user pool.
 
     Args:
-        ctx:
-        hub:
-        name(Text): The idem name for the resource
-        resource_id(Text, Optional): The identifier for this object. resource_arn in this case
+        name(str):
+            An Idem name of the resource.
+        resource_id(str, Optional):
+            The Amazon Resource Name (ARN) of the resource associated with the web ACL.
+
+            .. warning::
+              Idem automatically considers this resource being absent if this field is not specified.
+
+    Returns:
+        Dict[str, Any]
+
+    Request syntax:
+      .. code-block:: sls
+
+        [idem_test_aws_wafv2_associate_web_acl]:
+          aws.wafv2.associate_web_acl.absent:
+            - name: 'string'
+            - resource_id: 'string'
 
     Returns:
         Dict[str, Any]
 
     Examples:
-
         .. code-block:: sls
 
-            AWSServiceRoleForEC2Spot:
+            idem_test_aws_wafv2_associate_web_acl:
               aws.wafv2.associate_web_acl.absent:
-              - name: arn:aws:elasticloadbalancing:us-west-2:123456789012:loadbalancer/app/waf-cli-alb/1ea17125f8b25a2a
-              - resource_id: arn:aws:elasticloadbalancing:us-west-2:123456789012:loadbalancer/app/waf-cli-alb/1ea17125f8b25a2a
-
+                - name: 'idem_test_associate_web_acl'
+                - resource_id: 'arn:aws:apigateway:us-west-2::/restapis/1234567890/stages/dev'
     """
     result = dict(comment=(), old_state=None, new_state=None, name=name, result=True)
     if not resource_id:
@@ -193,24 +210,16 @@ async def absent(
 
 
 async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
-    r"""
-    **Autogenerated function**
-
-    Describe the resource in a way that can be recreated/managed with the corresponding "present" function
-
-    Retrieves the Amazon Resource Names (ARNs) for the regional resources that are associated with the specified web ACL
-
+    """Describes AWS WAF v2 regional resources associations with web ACLs in a way that can be recreated/managed with the corresponding "present" function.
 
     Returns:
-        Dict[str, Any]
+        Dict[str, Dict[str, Any]]
 
     Examples:
-
         .. code-block:: bash
 
             $ idem describe aws.wafv2.associate_web_acl
     """
-
     result = {}
     web_acls = await hub.exec.boto3.client.wafv2.list_web_acls(ctx, Scope="REGIONAL")
     resource_types = ["APPLICATION_LOAD_BALANCER", "API_GATEWAY", "APPSYNC"]
