@@ -18,6 +18,8 @@ async def modify(
     new_profile["region_name"] = _key_options(
         raw_profile, "region_name", "region", "location"
     )
+    if new_profile["region_name"] is None:
+        new_profile["region_name"] = hub.tool.boto3.region.get(ctx=None)
     new_profile["verify"] = raw_profile.get("verify", None)
     new_profile["use_ssl"] = raw_profile.get("use_ssl", True)
     new_profile["endpoint_url"] = _key_options(raw_profile, "endpoint_url", "endpoint")
