@@ -3,7 +3,7 @@ from typing import Any
 from typing import Dict
 
 
-async def convert_raw_acm_to_present(
+async def convert_raw_acm_to_present_async(
     hub,
     ctx,
     raw_resource: Dict[str, Any],
