@@ -6,7 +6,7 @@ from typing import Dict
 from typing import List
 
 
-async def convert_raw_deployment_to_present(
+def convert_raw_deployment_to_present(
     hub,
     raw_resource: Dict[str, Any],
     rest_api_id: str,
