@@ -10,14 +10,14 @@ Util functions for AWS API Gateway v2 Integration resources.
 def convert_raw_integration_to_present(
     hub, api_id: str, raw_resource: Dict[str, Any], idem_resource_name: str = None
 ) -> Dict[str, Any]:
-    r"""
+    """
     Convert AWS API Gateway v2 Integration resource to a common idem present state.
 
     Args:
         hub: required for functions in hub.
-        api_id(string): The API resource identifier in Amazon Web Services.
+        api_id(str): The API resource identifier in Amazon Web Services.
         raw_resource(Dict[str, Any]): The AWS response to convert.
-        idem_resource_name(string, optional): An Idem name of the resource.
+        idem_resource_name(str, Optional): An Idem name of the resource.
 
     Returns:
         Dict[str, Any]: Common idem present state
@@ -73,8 +73,8 @@ async def update(
     Updates an AWS API Gateway v2 Integration resource.
 
     Args:
-        api_id(string): The API resource identifier in Amazon Web Services.
-        resource_id(string): The Integration resource identifier in Amazon Web Services.
+        api_id(str): The API resource identifier in Amazon Web Services.
+        resource_id(str): The Integration resource identifier in Amazon Web Services.
         raw_resource(Dict): Existing resource parameters in Amazon Web Services.
         resource_parameters(Dict): Parameters from SLS file.
 
