@@ -7,14 +7,14 @@ from typing import Dict
 def convert_raw_route_to_present(
     hub, api_id: str, raw_resource: Dict[str, Any], idem_resource_name: str = None
 ) -> Dict[str, Any]:
-    r"""
+    """
     Convert AWS API Gateway v2 Route resource to a common idem present state.
 
     Args:
         hub: required for functions in hub.
-        api_id(string): The API resource identifier in Amazon Web Services.
+        api_id(str): The API resource identifier in Amazon Web Services.
         raw_resource(Dict[str, Any]): The AWS response to convert.
-        idem_resource_name(string, optional): An Idem name of the resource.
+        idem_resource_name(str, Optional): An Idem name of the resource.
 
     Returns:
         Dict[str, Any]: Common idem present state
