@@ -64,7 +64,7 @@ def convert_raw_auto_scaling_group_to_present(
     return result
 
 
-def is_auto_scaling_group_updated(
+def is_update_required(
     hub,
     current_state: Dict[str, Any],
     desired_state: Dict[str, Any],
@@ -78,11 +78,19 @@ def is_auto_scaling_group_updated(
         "termination_policies",
         "lifecycle_hook_specification_list",
     ]
-    dict_parameters = ["launch_template", "mixed_instances_policy"]
+    dict_parameters = ["mixed_instances_policy"]
     exclusion_list = ["tags"]
     for parameter in desired_state:
         if parameter in exclusion_list:
             continue
+
+        if (
+            parameter == "launch_configuration_name"
+            and parameter in current_state
+            and current_state.get(parameter) != desired_state.get(parameter)
+        ):
+            return True
+
         if desired_state.get(parameter) is None:
             # To favour optional parameters of resource
             continue
@@ -119,7 +127,16 @@ def is_auto_scaling_group_updated(
                 return True
             else:
                 continue
-        if current_state.get(parameter) != desired_state.get(parameter):
+        if parameter == "launch_template":
+            if desired_state.get(parameter):
+                current_launch_template = current_state.get(parameter, {})
+                for key, value in desired_state.get(parameter).items():
+                    if value != current_launch_template.get(key):
+                        return True
+            else:
+                continue
+
+        elif current_state.get(parameter) != desired_state.get(parameter):
             return True
     return False
 
