@@ -7,7 +7,7 @@ from typing import Dict
 UTC_FORMAT = "%Y-%m-%dT%H:%M:%SZ"
 
 
-async def convert_raw_budget_to_present(
+async def convert_raw_budget_to_present_async(
     hub, ctx, account_id: str, raw_resource: Dict[str, Any], idem_resource_name: str
 ) -> Dict[str, Any]:
     resource_id = raw_resource.get("BudgetName")
@@ -22,7 +22,6 @@ async def convert_raw_budget_to_present(
             "CalculatedSpend": "calculated_spend",
             "ForecastedSpend": "forecasted_spend",
             "BudgetType": "budget_type",
-            "LastUpdatedTime": "last_updated_time",
         }
     )
 
