@@ -3,7 +3,7 @@ from typing import Any
 from typing import Dict
 
 
-async def convert_raw_cloudtrail_to_present(
+async def convert_raw_cloudtrail_to_present_async(
     hub, ctx, raw_resource: Dict[str, Any], idem_resource_name: str
 ) -> Dict[str, Any]:
     resource_id = raw_resource.get("Name")
