@@ -49,7 +49,7 @@ def convert_raw_subscription_to_present(
     return resource_translated
 
 
-async def convert_raw_cost_category_to_present(
+async def convert_raw_cost_category_to_present_async(
     hub, ctx, raw_resource: Dict[str, Any], idem_resource_name: str
 ) -> Dict[str, Any]:
     resource_id = raw_resource.get("CostCategoryArn")
