@@ -1,3 +1,4 @@
+import base64
 from collections import OrderedDict
 from datetime import timezone
 from typing import Any
@@ -9,7 +10,7 @@ Util functions to convert raw resource state from AWS EC2 to present input forma
 UTC_FORMAT = "%Y-%m-%dT%H:%M:%SZ"
 
 
-async def convert_raw_vpc_to_present(
+async def convert_raw_vpc_to_present_async(
     hub, ctx, raw_resource: Dict[str, Any], idem_resource_name: str = None
 ) -> Dict[str, Any]:
     resource_id = raw_resource.get("VpcId")
@@ -420,7 +421,7 @@ def convert_raw_tg_vpc_attachment(
     return translated_resource
 
 
-async def convert_raw_dhcp_to_present(
+async def convert_raw_dhcp_to_present_async(
     hub, ctx, raw_resource: Dict[str, Any], idem_resource_name: str = None
 ) -> Dict[str, Any]:
     resource_id = raw_resource.get("DhcpOptionsId")
@@ -673,6 +674,7 @@ def convert_raw_vpc_endpoint_to_present(
             "PrivateDnsEnabled": "private_dns_enabled",
             "State": "state",
             "DnsOptions": "dns_options",
+            "DnsEntries": "dns_entries",
         }
     )
     resource_id = raw_resource.get("VpcEndpointId")
@@ -778,7 +780,7 @@ def convert_raw_availability_zone_to_snake_case(
     return resource_translated
 
 
-async def convert_raw_snapshot_to_present(
+async def convert_raw_snapshot_to_present_async(
     hub, ctx, raw_resource: Dict[str, Any], idem_resource_name: str
 ) -> Dict[str, Any]:
     """
@@ -949,5 +951,9 @@ def convert_raw_lauchtemplate_to_present(
             raw_resource.get("Tags")
         )
     resource_translated["version_description"] = raw_version.get("VersionDescription")
-    resource_translated["launch_template_data"] = raw_version.get("LaunchTemplateData")
+    launch_template_data = raw_version.get("LaunchTemplateData")
+    if launch_template_data.get("UserData"):
+        user_data = launch_template_data.get("UserData")
+        launch_template_data["UserData"] = base64.b64decode(user_data.encode()).decode()
+    resource_translated["launch_template_data"] = launch_template_data
     return resource_translated
