@@ -29,6 +29,10 @@ async def convert_instance_to_present_async(
                     "network_card_index": n.get("Attachment", {}).get(
                         "NetworkCardIndex"
                     ),
+                    "subnet_id": n.get("SubnetId"),
+                    "public_ip_address": n.get("Association", {}).get("PublicIp"),
+                    "private_ip_address": n.get("PrivateIpAddress"),
+                    "mac_address": n.get("MacAddress"),
                 }
                 for n in instance.get("NetworkInterfaces", [])
             ]
@@ -55,6 +59,7 @@ async def convert_instance_to_present_async(
                     sg.get("GroupId") for sg in instance.get("SecurityGroups", [])
                 ],
                 network_interfaces=network_interfaces,
+                public_ip_address=instance.get("PublicIpAddress"),
                 monitoring_enabled=instance.get("Monitoring", {}).get("State")
                 == "enabled",
                 root_device_name=instance.get("RootDeviceName"),
@@ -159,7 +164,15 @@ async def parse_block_device_mapping(hub, ctx, block_device_mappings):
         )
         if ebs.get("VolumeId"):
             new_bdm["volume_id"] = ebs["VolumeId"]
-        if ebs.get("DeleteOnTermination"):
+            ret = await hub.exec.boto3.client.ec2.describe_volumes(
+                ctx, VolumeIds=[ebs["VolumeId"]]
+            )
+            if ret and ret.ret.get("Volumes", ()):
+                volume = ret.ret.get("Volumes", ())[0]
+                new_bdm["size"] = volume.get("Size")
+                new_bdm["type"] = volume.get("VolumeType")
+                new_bdm["encrypted"] = volume.get("Encrypted")
+        if "DeleteOnTermination" in ebs:
             new_bdm["delete_on_termination"] = ebs["DeleteOnTermination"]
         new_block_device_mappings.append(new_bdm)
     return new_block_device_mappings
