@@ -61,9 +61,7 @@ async def apply(
         return False
 
     # Change the state of the instance to the opposite of the starting state
-    toggled_running_state = False
     if second_group:
-        toggled_running_state = True
         if initially_running:
             ret = await hub.exec.aws.ec2.instance.stop(ctx, instance_id=resource.id)
             result &= ret.result
@@ -93,20 +91,27 @@ async def apply(
     # If anything in the second group fails, revert the running state
     finally:
         # The running state is modified here
-        # If the new state requires a change in the instance, then leave the state alone
-        if toggled_running_state:
-            if initially_running or (new_value.get(RUNNING) is True):
-                ret = await hub.exec.aws.ec2.instance.start(
-                    ctx, instance_id=resource.id
-                )
-                result &= ret.result
-                if ret.comment:
-                    comments.append(ret.comment)
-            elif (not initially_running) or (new_value.get(RUNNING) is False):
-                ret = await hub.exec.aws.ec2.instance.stop(ctx, instance_id=resource.id)
-                result &= ret.result
-                if ret.comment:
-                    comments.append(ret.comment)
+        # Check the current state and match it with desired state
+        get = await hub.exec.aws.ec2.instance.get(ctx, resource_id=resource.id)
+        current_state = get.ret
+        result &= get.result
+        if get.comment:
+            comments.append(get.comment)
+
+        # Stop now if we can't get current state
+        if not result:
+            return False
+
+        if desired_state.get(RUNNING) and not current_state.get(RUNNING):
+            ret = await hub.exec.aws.ec2.instance.start(ctx, instance_id=resource.id)
+            result &= ret.result
+            if ret.comment:
+                comments.append(ret.comment)
+        elif not desired_state.get(RUNNING) and current_state.get(RUNNING):
+            ret = await hub.exec.aws.ec2.instance.stop(ctx, instance_id=resource.id)
+            result &= ret.result
+            if ret.comment:
+                comments.append(ret.comment)
 
     return result
 
