@@ -23,10 +23,10 @@ async def apply(
             comments.append(ret.comment)
         return ret.result
     else:
-        ret = await hub.exec.boto3.client.ec2.modfiy_instance_attribute(
+        ret = await hub.exec.boto3.client.ec2.modify_instance_attribute(
             ctx,
             InstanceId=resource.id,
-            Attribute="sourceDestCheck",
+            # Attribute="sourceDestCheck",
             SourceDestCheck={"Value": new_value},
         )
         if ret.comment:
