@@ -5,7 +5,6 @@ from typing import List
 async def search_raw(
     hub,
     ctx,
-    name,
     filters: List = None,
     resource_id: str = None,
 ) -> Dict:
@@ -13,10 +12,13 @@ async def search_raw(
     Fetch one or more placement groups from AWS. The return will be in the same format as what the boto3 api returns.
 
     Args:
-        name(str): The name of the Idem state and the GroupName of the placement group
-        filters(list, Optional): One or more filters. For example: {"Name": "strategy", "Values": ["cluster"]},
-        resource_id(str, Optional): The GroupName of the placement group.
-        A complete list of filters can be found at https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Client.describe_placement_groups
+        filters (list, Optional):
+            One or more filters. For example: {"Name": "strategy", "Values": ["cluster"]},
+            A complete list of filters can be found at https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Client.describe_placement_groups
+
+        resource_id (str, Optional):
+            The GroupName of the placement group.
+
     Returns:
         {"result": True|False, "comment": A message List, "ret": Dict}
 
