@@ -13,7 +13,7 @@ async def search_raw(
     Fetches a load balancer from AWS. The return will be in the same format as what the boto3 api returns.
 
     Args:
-        resource_id(Text): The name of the ElasticLoadBalancing Load Balancer. This name must be unique
+        resource_id(str): The name of the ElasticLoadBalancing Load Balancer. This name must be unique
             within your set of load balancers for the region, must have a maximum of 32 characters,
 
     Returns:
@@ -36,7 +36,7 @@ async def create(
     ctx,
     input_map: Dict[str, Any],
 ):
-    r"""
+    """
     Creates a Classic Load Balancer.
 
     Args:
@@ -106,7 +106,7 @@ async def update(
     resource_id: str,
     plan_state: Dict[str, Any],
 ):
-    r"""
+    """
     1. Associates one or more security groups with your load balancer in a virtual private cloud (VPC). The specified
        security groups override the previously associated security groups.
     2. Adds/Removes one or more subnets to the set of configured subnets for the specified load balancer. The load
@@ -131,10 +131,10 @@ async def update(
        in the VPC.
 
     Args:
-        name(Text):The name of the AWS ElasticLoadBalancing load balancer.
+        name(str):The name of the AWS ElasticLoadBalancing load balancer.
         current_state(Dict[str, Any]): response returned by describe on an AWS ElasticLoadBalancing load balancer
         input_map(Dict[str, Any]): a dictionary with newly passed values of params.
-        resource_id(Text): AWS ElasticLoadBalancing load balancer name.
+        resource_id(str): AWS ElasticLoadBalancing load balancer name.
         plan_state(Dict[str, Any]): idem --test state for update on AWS ElasticLoadBalancing Load Balancer.
 
     Returns:
