@@ -1,9 +1,8 @@
-from collections import OrderedDict
 from typing import Any
 from typing import Dict
 from typing import List
 
-from dict_tools import differ
+from dict_tools import data
 
 
 async def search_raw(
@@ -55,7 +54,6 @@ async def update(
     current_state: Dict[str, Any],
     input_map: Dict[str, Any],
     resource_id: str,
-    plan_state: Dict[str, Any],
 ):
     """
     1. Replaces the specified properties of the specified listener. Any property that is not updated, remains unchanged.
@@ -81,26 +79,49 @@ async def update(
         resource_id(str):
             AWS ElasticLoadBalancingv2 Listener Amazon Resource Name (ARN).
 
-        plan_state(dict[str, Any]):
-            idem --test state for update on AWS ElasticLoadBalancingv2 Listener.
-
     Returns:
         {"result": True|False, "comment": A message List, "ret": None}
     """
     result = dict(comment=[], result=True, ret=[])
-    if not ctx.get("test", False):
-        if input_map:
-            ret = compare_config(current_state=current_state, updated_state=input_map)
-            if (ret["result"] and ret["ret"]) or input_map.get("default_actions"):
+    if input_map:
+        update = {}
+        modify_params = {
+            "Port": "port",
+            "Protocol": "protocol",
+            "SslPolicy": "ssl_policy",
+            "AlpnPolicy": "alpn_policy",
+            "Certificates": "default_certificates",
+        }
+        hub.log.debug(
+            f"Current state of ELBv2 Listener '{name}' with resource id '{resource_id}' before update: {current_state}"
+        )
+        for param_raw, param_present in modify_params.items():
+            if input_map.get(param_present) is not None and current_state.get(
+                param_present
+            ) != input_map.get(param_present):
+                update[param_raw] = input_map[param_present]
+
+        if len(input_map.get("default_actions")) == len(
+            current_state.get("default_actions")
+        ):
+            ret = are_default_actions_identical(
+                old_actions=current_state.get("default_actions"),
+                new_actions=input_map.get("default_actions"),
+            )
+            if not ret["result"]:
+                update["DefaultActions"] = input_map["default_actions"]
+        else:
+            update["DefaultActions"] = input_map["default_actions"]
+
+        hub.log.debug(
+            f"Params to modify for ELBv2 Listener '{name}' with resource id '{resource_id}': {update}"
+        )
+        if update:
+            if not ctx.get("test", False):
                 modify_listener = await hub.exec.boto3.client.elbv2.modify_listener(
                     ctx,
                     ListenerArn=resource_id,
-                    Port=ret["ret"].get("Port"),
-                    Protocol=ret["ret"].get("Protocol"),
-                    SslPolicy=ret["ret"].get("SslPolicy"),
-                    Certificates=ret["ret"].get("DefaultCertificates"),
-                    DefaultActions=input_map.get("default_actions"),
-                    AlpnPolicy=ret["ret"].get("AlpnPolicy"),
+                    **update,
                 )
                 if not modify_listener["result"]:
                     result["comment"] = list(modify_listener["comment"])
@@ -108,14 +129,26 @@ async def update(
                     return result
                 result["comment"].append("Modified Listener.")
                 result["ret"].append(
-                    {"modify_listener": modify_listener["ret"]["Listeners"][0]}
+                    {
+                        "Key": "modify_listener",
+                        "Value": modify_listener["ret"]["Listeners"][0],
+                    }
                 )
+            else:
+                for key, val in update.items():
+                    result["ret"].append(
+                        {
+                            "Key": modify_params.get(key),
+                            "Value": val,
+                        }
+                    )
 
-        if input_map.get("certificates"):
-            ret = compare_certificates(
-                old_certificates=current_state.get("certificates"),
-                new_certificates=input_map.get("certificates"),
-            )
+    if input_map.get("certificates"):
+        ret = compare_certificates(
+            old_certificates=current_state.get("certificates"),
+            new_certificates=input_map.get("certificates"),
+        )
+        if not ctx.get("test", False):
             if ret["ret"]:
                 if ret["ret"].get("to_remove"):
                     remove_certificates = (
@@ -130,6 +163,10 @@ async def update(
                         result["result"] = False
                         return result
                     result["comment"].append("Removed Certificates.")
+                    hub.log.debug(
+                        f"Removed Certificates for ELBv2 Listener '{name}' with resource id '{resource_id}':"
+                        f" {ret['ret'].get('to_remove')}"
+                    )
                     result["ret"].append(
                         {"remove_certificates": remove_certificates["ret"]}
                     )
@@ -147,26 +184,18 @@ async def update(
                         result["result"] = False
                         return result
                     result["comment"].append("Added Certificates.")
-                    result["ret"].append({"add_certificates": add_certificates["ret"]})
-    else:
-        update_params = OrderedDict(
-            {
-                "name": name,
-                "default_actions": input_map.get("default_actions"),
-                "protocol": input_map.get("protocol"),
-                "port": input_map.get("port"),
-                "ssl_policy": input_map.get("ssl_policy"),
-                "certificates": input_map.get("certificates"),
-                "default_certificates": input_map.get("default_certificates"),
-                "alpn_policy": input_map.get("alpn_policy"),
-                "tags": input_map.get("tags"),
-                "resource_id": resource_id,
-            }
-        )
-        for key, value in update_params.items():
-            if value is not None:
-                plan_state[key] = value
-        result["ret"] = plan_state
+                    hub.log.debug(
+                        f"Added Certificates for ELBv2 Listener '{name}' with resource id '{resource_id}': "
+                        f"{ret['ret'].get('to_add')}"
+                    )
+                    result["ret"].append(
+                        {"Key": "certificates", "Value": ret["ret"]["to_add"]}
+                    )
+        else:
+            if ret["ret"].get("to_add"):
+                result["ret"].append(
+                    {"Key": "certificates", "Value": ret["ret"]["to_add"]}
+                )
     return result
 
 
@@ -184,8 +213,7 @@ def compare_certificates(
         new_certificates(list[dict[str, Any]]):
             Newer list of certificates to be added to AWS ElasticLoadBalancingv2 Listener.
 
-    Returns:
-        {"comment": ("A tuple",), "ret": Dict}
+    Returns: Dict[str, Dict]
 
     """
     result = dict(ret=None)
@@ -206,43 +234,44 @@ def compare_certificates(
     return result
 
 
-def compare_config(current_state: Dict[str, Any], updated_state: Dict[str, Any]):
+def are_default_actions_identical(
+    old_actions: List[Dict[str, Any]] = None,
+    new_actions: List[Dict[str, Any]] = None,
+):
     """
-    Compares listener's existing configuration with newly passed inputs and returns details of the diff.
+    Compares old_actions and new_actions and return the new list of default_actions that need to be updated.
 
     Args:
-        current_state (dict[str, Any]):
-            response returned by describe on an AWS ELBv2 Listener
+        old_actions(list[dict[str, Any]]):
+            Existing list of default_actions to be removed from AWS ElasticLoadBalancingv2 Listener.
 
-        updated_state (dict[st, Any]):
-            Newly passed values for update function as dictionary .
+        new_actions(list[dict[str, Any]]):
+            Newer list of default_actions to be added to AWS ElasticLoadBalancingv2 Listener.
 
-    Returns:
-        {"result": True|False, "ret": Dict}
+    Returns: Dict[str, Dict]
 
     """
-    result = dict(result=False, ret={})
-    target_group_params = {
-        "Port": "port",
-        "Protocol": "protocol",
-        "SslPolicy": "ssl_policy",
-        "AlpnPolicy": "alpn_policy",
-        "DefaultCertificates": "default_certificates",
-    }
-    current_config_mapping = {}
-    for name, value in target_group_params.items():
-        if current_state.get(value):
-            current_config_mapping[name] = current_state.get(value)
-
-    updated_config_mapping = {}
-    for name, value in target_group_params.items():
-        if updated_state.get(value):
-            updated_config_mapping[name] = updated_state.get(value)
-
-    diff_in_config = differ.deep_diff(current_config_mapping, updated_config_mapping)
-
-    if diff_in_config.get("new"):
-        result["result"] = True
-        result["ret"] = diff_in_config.get("new")
+    result = dict(result=False)
+    for new_action in new_actions:
+        is_found = False
+        for old_action in old_actions:
+            if new_action.get("Type") == old_action.get("Type"):
+                is_found = True
+                if len(old_action) != len(new_action):
+                    return result
 
+                for key, value in old_action.items():
+                    if new_action.get(key):
+                        if isinstance(value, Dict):
+                            if data.recursive_diff(
+                                value, new_action.get(key), ignore_order=True
+                            ):
+                                return result
+                        elif value != new_action.get(key):
+                            return result
+                    else:
+                        return result
+        if not is_found:
+            return result
+    result["result"] = True
     return result
