@@ -1,8 +1,8 @@
 from typing import Any
 from typing import Dict
 from typing import List
-from typing import OrderedDict
 
+from dict_tools import data
 from dict_tools import differ
 
 
@@ -88,29 +88,36 @@ async def update(
 
     """
     result = dict(comment=[], result=True, ret=[])
-    if not ctx.get("test", False):
-        if input_map:
-            ret = compare_config(current_state=current_state, updated_state=input_map)
-            if ret["result"] and ret["ret"]:
+    if input_map:
+        update = {}
+        modify_params = {
+            "HealthCheckProtocol": "health_check_protocol",
+            "HealthCheckPort": "health_check_port",
+            "HealthCheckPath": "health_check_path",
+            "HealthCheckEnabled": "health_check_enabled",
+            "HealthCheckIntervalSeconds": "health_check_interval_seconds",
+            "HealthCheckTimeoutSeconds": "health_check_timeout_seconds",
+            "HealthyThresholdCount": "healthy_threshold_count",
+            "UnhealthyThresholdCount": "unhealthy_threshold_count",
+            "Matcher": "matcher",
+        }
+        hub.log.debug(
+            f"Current state of ELBv2 Target Group '{name}' with resource id '{resource_id}' before update: "
+            f"{current_state}"
+        )
+        for param_raw, param_present in modify_params.items():
+            if input_map.get(param_present) is not None and current_state.get(
+                param_present
+            ) != input_map.get(param_present):
+                update[param_raw] = input_map[param_present]
+
+        if update:
+            if not ctx.get("test", False):
                 modify_target_group = (
                     await hub.exec.boto3.client.elbv2.modify_target_group(
                         ctx,
                         TargetGroupArn=resource_id,
-                        HealthCheckProtocol=ret["ret"].get("HealthCheckProtocol"),
-                        HealthCheckPort=ret["ret"].get("HealthCheckPort"),
-                        HealthCheckPath=ret["ret"].get("HealthCheckPath"),
-                        HealthCheckEnabled=ret["ret"].get("HealthCheckEnabled"),
-                        HealthCheckIntervalSeconds=ret["ret"].get(
-                            "HealthCheckIntervalSeconds"
-                        ),
-                        HealthCheckTimeoutSeconds=ret["ret"].get(
-                            "HealthCheckTimeoutSeconds"
-                        ),
-                        HealthyThresholdCount=ret["ret"].get("HealthyThresholdCount"),
-                        UnhealthyThresholdCount=ret["ret"].get(
-                            "UnhealthyThresholdCount"
-                        ),
-                        Matcher=ret["ret"].get("Matcher"),
+                        **update,
                     )
                 )
                 if not modify_target_group["result"]:
@@ -122,36 +129,46 @@ async def update(
                         resource_type="aws.elbv2.target_group", name=name
                     )
                 )
+            for key, value in update.items():
+                result["ret"].append({"Key": modify_params.get(key), "Value": value})
+
+    if input_map.get("attributes"):
+        ret = hub.tool.aws.elbv2.load_balancer.compare_attributes(
+            old_attributes=current_state.get("attributes"),
+            new_attributes=input_map.get("attributes"),
+        )
+        if not ctx.get("test", False):
+            if ret["ret"].get("modify"):
+                modify_attributes = (
+                    await hub.exec.boto3.client.elbv2.modify_target_group_attributes(
+                        ctx,
+                        TargetGroupArn=resource_id,
+                        Attributes=ret["ret"].get("modify"),
+                    )
+                )
+                if not modify_attributes["result"]:
+                    result["comment"] += list(modify_attributes["comment"])
+                    result["result"] = False
+                    return result
+                result["comment"].append("Modified Attributes.")
                 result["ret"].append(
                     {
-                        "modify_target_group": modify_target_group["ret"][
-                            "TargetGroups"
-                        ][0]
+                        "Key": "attributes",
+                        "Value": modify_attributes["ret"]["Attributes"],
                     }
                 )
-
-        if input_map.get("attributes"):
-            modify_attributes = (
-                await hub.exec.boto3.client.elbv2.modify_target_group_attributes(
-                    ctx,
-                    TargetGroupArn=resource_id,
-                    Attributes=input_map.get("attributes"),
+        else:
+            if ret["ret"].get("modify"):
+                result["ret"].append(
+                    {"Key": "attributes", "Value": ret["ret"].get("attributes")}
                 )
-            )
-            if not modify_attributes["result"]:
-                result["comment"] += list(modify_attributes["comment"])
-                result["result"] = False
-                return result
-            result["comment"].append("Modified Attributes.")
-            result["ret"].append(
-                {"modify_attributes": modify_attributes["ret"]["Attributes"]}
-            )
 
-        if input_map.get("targets"):
-            ret = compare_targets(
-                old_targets=current_state.get("targets"),
-                new_targets=input_map.get("targets"),
-            )
+    if input_map.get("targets"):
+        ret = compare_targets(
+            old_targets=current_state.get("targets"),
+            new_targets=input_map.get("targets"),
+        )
+        if not ctx.get("test", False):
             if ret["ret"]:
                 if ret["ret"]["to_deregister"]:
                     deregister_targets = (
@@ -166,8 +183,9 @@ async def update(
                         result["result"] = False
                         return result
                     result["comment"].append("Deregistered Targets.")
-                    result["ret"].append(
-                        {"deregister_targets": deregister_targets["ret"]}
+                    hub.log.debug(
+                        f"De-registered targets for ELBv2 Target Group '{name}' with resource id '{resource_id}': "
+                        f"{ret['ret']['to_deregister']}"
                     )
 
                 if ret["ret"]["to_register"]:
@@ -183,80 +201,18 @@ async def update(
                         result["result"] = False
                         return result
                     result["comment"].append("Registered Targets.")
-                    result["ret"].append({"register_targets": register_targets["ret"]})
-    else:
-        update_params = OrderedDict(
-            {
-                "name": name,
-                "protocol": input_map.get("protocol"),
-                "protocol_version": input_map.get("protocol_version"),
-                "port": input_map.get("port"),
-                "vpc_id": input_map.get("vpc_id"),
-                "health_check_protocol": input_map.get("health_check_protocol"),
-                "health_check_port": input_map.get("health_check_port"),
-                "health_check_enabled": input_map.get("health_check_enabled"),
-                "health_check_path": input_map.get("health_check_path"),
-                "health_check_interval_seconds": input_map.get(
-                    "health_check_interval_seconds"
-                ),
-                "health_check_timeout_seconds": input_map.get(
-                    "health_check_timeout_seconds"
-                ),
-                "healthy_threshold_count": input_map.get("healthy_threshold_count"),
-                "unhealthy_threshold_count": input_map.get("unhealthy_threshold_count"),
-                "matcher": input_map.get("matcher"),
-                "target_type": input_map.get("target_type"),
-                "tags": input_map.get("tags"),
-                "ip_address_type": input_map.get("ip_address_type"),
-                "resource_id": resource_id,
-                "targets": input_map.get("targets"),
-            }
-        )
-        for key, value in update_params.items():
-            if value is not None:
-                plan_state[key] = value
-        result["ret"] = plan_state
-    return result
-
-
-def compare_config(current_state: Dict[str, Any], updated_state: Dict[str, Any]):
-    """
-    Compares target group's existing configuration with newly passed input config and returns details of the diff.
-
-    Args:
-        current_state (Dict[str, Any]): response returned by describe on an AWS ELBv2 Target Group
-        updated_state (Dict[st, Any]): a dictionary with newly passed values of params.
-
-    Returns:
-        {"result": True|False, "ret": Dict}
-
-    """
-    result = dict(result=False, ret=None)
-    target_group_params = {
-        "HealthCheckProtocol": "health_check_protocol",
-        "HealthCheckPort": "health_check_port",
-        "HealthCheckPath": "health_check_path",
-        "HealthCheckEnabled": "health_check_enabled",
-        "HealthCheckIntervalSeconds": "health_check_interval_seconds",
-        "HealthCheckTimeoutSeconds": "health_check_timeout_seconds",
-        "HealthyThresholdCount": "healthy_threshold_count",
-        "UnhealthyThresholdCount": "unhealthy_threshold_count",
-        "Matcher": "matcher",
-    }
-    current_config_mapping = {}
-    for name, value in target_group_params.items():
-        if current_state.get(value):
-            current_config_mapping[name] = current_state.get(value)
-
-    updated_config_mapping = {}
-    for name, value in target_group_params.items():
-        if updated_state.get(value):
-            updated_config_mapping[name] = updated_state.get(value)
-
-    diff_in_config = differ.deep_diff(current_config_mapping, updated_config_mapping)
-    if diff_in_config.get("new"):
-        result["result"] = True
-        result["ret"] = diff_in_config.get("new")
+                    hub.log.debug(
+                        f"Registered targets for ELBv2 Target Group '{name}' with resource id '{resource_id}': "
+                        f"{ret['ret']['to_register']}"
+                    )
+                    result["ret"].append(
+                        {"Key": "targets", "Value": ret["ret"]["to_register"]}
+                    )
+        else:
+            if ret["ret"]["to_register"]:
+                result["ret"].append(
+                    {"Key": "targets", "Value": ret["ret"]["to_register"]}
+                )
     return result
 
 
@@ -278,7 +234,6 @@ def compare_targets(
 
     """
     result = dict(ret=None)
-    to_deregister = []
     to_register = []
     old_targets_map = {target.get("Id"): target for target in old_targets or []}
     if new_targets is not None:
