@@ -8,7 +8,7 @@ Util functions to convert raw CloudWatchEvents Rule resource state from AWS to p
 """
 
 
-async def convert_raw_cloud_watch_rule_to_present(
+async def convert_raw_cloud_watch_rule_to_present_async(
     hub,
     ctx,
     raw_resource: Dict[str, Any],
