@@ -34,7 +34,7 @@ def convert_raw_instance_profile_to_present(
     return translated_resource
 
 
-async def convert_raw_policy_to_present(
+def convert_raw_policy_to_present(
     hub, ctx, raw_resource: Dict[str, Any]
 ) -> Dict[str, Any]:
     resource_parameters = OrderedDict(
