@@ -7,10 +7,7 @@ def convert_raw_service_linked_role_to_present(
     hub, raw_resource: Dict[str, Any]
 ) -> Dict[str, Any]:
     resource_parameters = OrderedDict(
-        {
-            "RoleName": "name",
-            "Description": "description",
-        }
+        {"RoleName": "name", "Description": "description", "Arn": "arn"}
     )
 
     # RoleName is the unique identifier for policy so it is set as resource_id
