@@ -42,7 +42,7 @@ async def update(
     plan_state: Dict[str, Any],
     timeout: Dict[str, Any],
 ):
-    r"""
+    """
     If the input supplied retention is less than the existing, here we decerase the Kinesis data stream's retention
     period, which is the length of time data records are accessible after they are added to the stream. The minimum
     value of a stream's retention period is 24 hours. This operation may result in lost data. For example, if the
@@ -93,7 +93,7 @@ async def update(
         plan_state(dict[str, Any]):
             idem --test state for update on AWS ElasticLoadBalancingv2 Listener.
 
-        timeout(dict, optional): Timeout configuration for waiting for Aws Certificate to get issued.
+        timeout(dict, Optional): Timeout configuration for waiting for Aws Certificate to get issued.
             * describe (Dict) -- Timeout configuration for describing certificate
                 * delay (int, Optional): The amount of time in seconds to wait between attempts.
                 * max_attempts (int, Optional): Customized timeout configuration containing delay and max attempts.
@@ -406,8 +406,8 @@ async def kinesis_waiter(
     Waiter to wait for the Kinesis Stream to become active.
 
         Args:
-           name(Text): An Idem name of the resource.
-           timeout(Dict, optional): Timeout configuration for creating or updating Kinesis Stream.
+           name(str): An Idem name of the resource.
+           timeout(Dict, Optional): Timeout configuration for creating or updating Kinesis Stream.
             * create (Dict) -- Timeout configuration for creating Kinesis Stream
                 * delay(int, default=10) -- The amount of time in seconds to wait between attempts.
                 * max_attempts(int, default=18) -- Customized timeout configuration containing delay and max attempts.
