@@ -5,7 +5,7 @@ from typing import Dict
 from typing import List
 
 
-async def convert_raw_db_cluster_to_present(
+def convert_raw_db_cluster_to_present(
     hub,
     raw_resource: Dict[str, Any],
     idem_resource_name: str = None,
@@ -106,7 +106,7 @@ async def get_present_db_cluster(
     tags = tags["ret"]
     result[
         "present_db_cluster"
-    ] = await hub.tool.aws.neptune.db_cluster.convert_raw_db_cluster_to_present(
+    ] = hub.tool.aws.neptune.db_cluster.convert_raw_db_cluster_to_present(
         raw_resource=raw_db_cluster_result["ret"]["DBClusters"][0],
         idem_resource_name=name,
         tags=tags,
