@@ -14,9 +14,9 @@ async def search_raw(
     Fetch one or more neptune db instances from AWS. The return will be in the same format as what the boto3 api returns.
 
     Args:
-        name(string): The name of the Idem state.
-        resource_id(string, optional): AWS Neptune DBInstanceIdentifier to identify the resource.
-        filters(list, optional): A filter that specifies one or more DB instances to describe.
+        name(str): The name of the Idem state.
+        resource_id(str, Optional): AWS Neptune DBInstanceIdentifier to identify the resource.
+        filters(list, Optional): A filter that specifies one or more DB instances to describe.
             Supported filters:
             db-cluster-id - Accepts DB cluster identifiers and DB cluster Amazon Resource Names (ARNs). The results list will only include information about the DB instances associated with the DB clusters identified by these ARNs.
             engine - Accepts an engine name (such as neptune ), and restricts the results list to DB instances created by that engine.
