@@ -148,3 +148,10 @@ def convert_raw_account_to_present(
             tags = hub.tool.aws.tag_utils.convert_tag_list_to_dict(tags)
         resource_translated["tags"] = tags
     return resource_translated
+
+
+def convert_raw_organizations_policy_attachment_to_present(
+    hub, policy_id: str, target_id: str
+) -> Dict[str, Any]:
+    translated_resource = {"policy_id": policy_id, "target_id": target_id}
+    return translated_resource
