@@ -9,17 +9,20 @@ Util functions to convert raw resource state from AWS EC2 to present input forma
 
 
 def convert_raw_db_subnet_group_to_present(
-    hub, resource: Dict[str, Any], tags: List = None, idem_resource_name: str = None
+    hub,
+    resource: Dict[str, Any],
+    tags: List = None,
+    idem_resource_name: str = None,
 ) -> Dict[str, Any]:
-    new_resource = {}
     db_subnet_group_id = resource.get("DBSubnetGroupName")
     describe_parameters = OrderedDict(
         {
+            "DBSubnetGroupName": "name",
             "DBSubnetGroupDescription": "db_subnet_group_description",
             "DBSubnetGroupArn": "db_subnet_group_arn",
         }
     )
-    new_resource = {"name": db_subnet_group_id, "resource_id": db_subnet_group_id}
+    new_resource = {"name": idem_resource_name, "resource_id": db_subnet_group_id}
     for parameter_old_key, parameter_new_key in describe_parameters.items():
         if resource.get(parameter_old_key) is not None:
             new_resource[parameter_new_key] = resource.get(parameter_old_key)
@@ -39,7 +42,6 @@ def convert_raw_db_subnet_group_to_present(
 def convert_raw_db_cluster_to_present(
     hub, raw_resource: Dict[str, Any], idem_resource_name: str = None
 ) -> Dict[str, Any]:
-
     resource_parameters = OrderedDict(
         {
             "AvailabilityZones": "availability_zone",
@@ -47,6 +49,7 @@ def convert_raw_db_cluster_to_present(
             "CharacterSetName": "character_set_name",
             "DatabaseName": "database_name",
             "DBClusterIdentifier": "db_cluster_identifier",
+            "DBClusterArn": "db_cluster_arn",
             "Engine": "engine",
             "EngineVersion": "engine_version",
             "Port": "port",
@@ -124,10 +127,10 @@ def convert_raw_db_instance_to_present(
     raw_resource_tags: Dict[str, Any],
     idem_resource_name: str = None,
 ) -> Dict[str, Any]:
-
     resource_parameters = OrderedDict(
         {
             "DBName": "db_name",
+            "DBInstanceArn": "db_instance_arn",
             "AllocatedStorage": "allocated_storage",
             "DBInstanceClass": "db_instance_class",
             "Engine": "engine",
@@ -231,14 +234,12 @@ def convert_raw_db_instance_to_present(
     return resource_translated
 
 
-async def convert_db_parameter_group_to_present(
+def convert_db_parameter_group_to_present(
     hub,
     raw_resource: Dict[str, Any],
     tags: List = None,
     parameters: List = None,
-    idem_resource_name: str = None,
 ) -> Dict[str, Any]:
-    new_resource = {}
     describe_parameters = OrderedDict(
         {
             "DBParameterGroupName": "resource_id",
@@ -254,7 +255,7 @@ async def convert_db_parameter_group_to_present(
     if tags:
         new_resource["tags"] = tags
     if parameters:
-        new_resource["parameters"] = parameters
+        new_resource["parameters"] = _convert_parameters(parameters)
     return new_resource
 
 
@@ -286,6 +287,23 @@ def convert_raw_db_cluster_parameter_group_to_present(
         resource_translated["tags"] = tags
 
     if parameters:
-        resource_translated["parameters"] = parameters
+        resource_translated["parameters"] = _convert_parameters(parameters)
 
     return resource_translated
+
+
+def _convert_parameters(parameters: List = None):
+    # Extract only the relevant attributes for parameters, those that are used by present
+    if parameters is None:
+        return None
+    converted_params: List[Dict[str, Any]] = []
+    for param in parameters:
+        converted_params.append(
+            {
+                "ParameterName": param.get("ParameterName"),
+                "ParameterValue": param.get("ParameterValue"),
+                "ApplyMethod": param.get("ApplyMethod"),
+            }
+        )
+
+    return converted_params
