@@ -1,8 +1,8 @@
-def get(hub, ctx) -> str:
+def get(hub, ctx=None) -> str:
     """
     Get the region name from ctx and fall back to the region in config
     """
-    if ctx.acct.get("region_name"):
+    if ctx and ctx.acct.get("region_name"):
         hub.log.trace("Using region name from acct profile")
         return ctx.acct["region_name"]
 
